/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//! \file   drivers/drvic/pga411q1/src/32b/f28x/f2806x/pga411q1.c
//! \brief  Contains the various functions related to the PGA411Q1 object
//!
//! (C) Copyright 2015, Texas Instruments, Inc.


// **************************************************************************
// the includes

#include <math.h>


// **************************************************************************
// drivers
#include "sw/drivers/drvic/pga411q1/src/32b/f28x/f2806x/pga411q1.h"


// **************************************************************************
// modules


// **************************************************************************
// platforms


// **************************************************************************
// the defines


// **************************************************************************
// the globals


// **************************************************************************
// the function prototypes
/* CRC6 calculation - optimized for PGA411 */
uint16_t PGA411Q1_CRC2_CAL(uint32_t data)
{
    uint16_t byte_idx, bit_idx, crc = (CRC_INITSEED << 2);

    /* byte by byte starting from most significant (3-2-1) */
    for (byte_idx = CRC_BYTECOUNT; byte_idx >= 1; byte_idx--)
    {
        /* XOR-in new byte from left to right */
        crc ^= ((data >> (byte_idx << 3)) & 0x000000FF);

        /* bit by bit for each byte */
        for (bit_idx = 0; bit_idx < 8; bit_idx++)
        {
            crc = crc << 1 ^ (crc & 0x80 ? (CRC_POLYNOM << 2) : 0);
        }
    }

    return (crc >> 2 & CRC_INITSEED); /*restore two bit offset */
}


PGA411Q1_Handle PGA411Q1_init(void *pMemory,const size_t numBytes)
{
  PGA411Q1_Handle handle;

  if(numBytes < sizeof(PGA411Q1_Obj))
    return((PGA411Q1_Handle)NULL);

  // assign the handle
  handle = (PGA411Q1_Handle)pMemory;

  PGA411Q1_resetRxTimeout(handle);
  PGA411Q1_resetEnableTimeout(handle);

  return(handle);
} // end of PGA411Q1_init() function


void PGA411Q1_setSpiHandle(PGA411Q1_Handle handle,SPI_Handle spiHandle)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the serial peripheral interface object
  obj->spiHandle = spiHandle;

  return;
} // end of PGA411Q1_setSpiHandle() function


void PGA411Q1_setGpioHandle(PGA411Q1_Handle handle,GPIO_Handle gpioHandle)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioHandle = gpioHandle;

  return;
} // end of PGA411Q1_setGpioHandle() function


void PGA411Q1_setGpioSpiCsNumber(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioSpiCsNumber = gpioNumber;

  return;
} // end of PGA411Q1_setGpioSpiCsNumber() function

void PGA411Q1_setGpioVa0Number(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioVa1Number = gpioNumber;

  return;
} // end of PGA411Q1_setGpioVa0Number() function

void PGA411Q1_setGpioVa1Number(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioVa1Number = gpioNumber;

  return;
} // end of PGA411Q1_setGpioVa1Number() function

void PGA411Q1_setGpioAmodeNumber(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioAmodeNumber = gpioNumber;

  return;
} // end of PGA411Q1_setGpioAmodeNumber() function

void PGA411Q1_setGpioBmode0Number(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioBmode0Number = gpioNumber;

  return;
} // end of PGA411Q1_setGpioBmode0Number() function

void PGA411Q1_setGpioOmodeNumber(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioOmodeNumber = gpioNumber;

  return;
} // end of PGA411Q1_setGpioOmodeNumber() function

void PGA411Q1_setGpioInhbNumber(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioInhbNumber = gpioNumber;

  return;
} // end of PGA411Q1_setGpioInhbNumber() function

void PGA411Q1_setGpioFaultNumber(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioFaultNumber = gpioNumber;

  return;
} // end of PGA411Q1_setGpioFaultNumber() function

void PGA411Q1_setGpioSFaultResNumber(PGA411Q1_Handle handle,GPIO_Number_e gpioNumber)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioFaultResNumber = gpioNumber;

  return;
} // end of PGA411Q1_setGpioSFaultResNumber() function

void PGA411Q1_setDatMode(PGA411Q1_Handle handle)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;

  // Reset Fault
  GPIO_setHigh(obj->gpioHandle, obj->gpioFaultResNumber);

  // BMODE=1, 12bit resolution
  GPIO_setHigh(obj->gpioHandle, obj->gpioBmode0Number);

  // AMODE=0, disable accelerated mode
  GPIO_setLow(obj->gpioHandle, obj->gpioAmodeNumber);

  //
  //  VA0 | VA1 | ORD [11:0] Function
  // ----+-----+------------------------------
  //  0  |  0  |  Hi-Z
  //  1  |  1  |  Hi-Z
  //  0  |  1  |  Angle Output at ORD [11:0]
  //  1  |  0  |  Velocity output at ORD [11:0]
  //
  // VA0, VA1, Output selection
  GPIO_setLow(obj->gpioHandle, obj->gpioVa0Number);
  GPIO_setHigh(obj->gpioHandle, obj->gpioVa1Number);


  GPIO_setLow(obj->gpioHandle, obj->gpioFaultResNumber);

} // end of PGA411Q1_Reset() function

void PGA411Q1_Reset(PGA411Q1_Handle handle)
{

} // end of PGA411Q1_Reset() function

uint32_t PGA411Q1_readSpi(PGA411Q1_Handle handle,const uint16_t regAddrCmd)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;
  PGA411Q1_spi_frame_t dataOut, dataIn;
  uint16_t n;
  static volatile uint16_t WaitTimeOut = 0;
  volatile SPI_FifoStatus_e RxFifoCnt = SPI_FifoStatus_Empty;

  // build the control word
  dataOut.AddrData.addr = regAddrCmd;
  dataOut.AddrData.stat = 0x00;
  dataOut.AddrData.data = 0x00F0;
  dataOut.AddrData.crc = 0x00;

  dataOut.AddrData.crc = PGA411Q1_CRC2_CAL(dataOut.frame);

  // reset the Rx fifo pointer to zero
  SPI_resetTxFifo(obj->spiHandle);
  SPI_resetRxFifo(obj->spiHandle);

  SPI_enableRxFifo(obj->spiHandle);

  GPIO_setLow(obj->gpioHandle, obj->gpioSpiCsNumber);

  // wait for registers to update
  for(n=0;n<0x05;n++)
    asm(" NOP");

  // write the command
  SPI_write(obj->spiHandle,dataOut.dataWord.dataH);
  SPI_write(obj->spiHandle,dataOut.dataWord.dataL);

  // wait for registers to send
  for(n=0;n<0x03F;n++)
    asm(" NOP");

  // wait for the response to populate the RX fifo, else a wait timeout will occur
  while((RxFifoCnt < SPI_FifoStatus_2_Words) && (WaitTimeOut < 0xffff))
  {
    RxFifoCnt = SPI_getRxFifoStatus(obj->spiHandle);

    if(++WaitTimeOut > 0xfffe)
    {
        obj->RxTimeOut = true;
    }
  }

  // Read the word
  dataIn.dataWord.dataL = SPI_readEmu(obj->spiHandle);
  dataIn.dataWord.dataH = SPI_readEmu(obj->spiHandle);

  for(n=0;n<0x01F;n++)
    asm(" NOP");

  GPIO_setHigh(obj->gpioHandle, obj->gpioSpiCsNumber);

  return(dataIn.frame);
} // end of PGA411Q1_readSpi() function


void PGA411Q1_writeSpi(PGA411Q1_Handle handle,const uint16_t regAddrCmd,const uint16_t data)
{
  PGA411Q1_Obj *obj = (PGA411Q1_Obj *)handle;
  uint16_t ctrlWord;
  uint16_t n;

  // build the control word
  ctrlWord = (uint16_t)PGA411Q1_buildCtrlWord(regAddrCmd,data);

  // reset the Rx fifo pointer to zero
  SPI_resetRxFifo(obj->spiHandle);
  SPI_enableRxFifo(obj->spiHandle);

  GPIO_setLow(obj->gpioHandle, obj->gpioSpiCsNumber);

  // wait for GPIO
  for(n=0;n<0x03;n++)
    asm(" NOP");

  // write the command
  SPI_write(obj->spiHandle,ctrlWord);

  // wait for registers to update
  for(n=0;n<0x0FF;n++)
    asm(" NOP");

  GPIO_setHigh(obj->gpioHandle, obj->gpioSpiCsNumber);

  return;
}  // end of PGA411Q1_writeSpi() function


/* Change state diagnostic/normal */
void PGA411Q1_State(PGA411Q1_Handle handle, RDC_SPI_PGA411_Vars_t *Spi_pga411q1_Vars)
{
    Uint16 temp;

    /* Enter Diagnostic state */
    if (state == DIAG)
    {
        /* read content of  DEV_CONTROL3 register */
        temp = pga411_ReadReg(DEV_CONTROL3);
        temp |= 0x0004; /* set bit SPIDIAG */
        pga411_WriteReg(DEV_CONTROL3, temp); /* finish R-M-W */
    }
    /* Go back to normal state */
    else
    {
        /* read content of  DEV_CONTROL1 register */
        temp = pga411_ReadReg(DEV_CONTROL1);
        temp |= 0x0001; /* set bit DIAGEXIT */
        pga411_WriteReg(DEV_CONTROL1, temp); /* finish R-M-W */
    }
}

void PGA411Q1_setupSpi(PGA411Q1_Handle handle, RDC_SPI_PGA411_Vars_t *Spi_pga411q1_Vars)
{

  return;
}

// end of file
