/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//! \file   drivers/drvic/tps65381a/src/32b/f28x/f2806x/tps65381a.c
//! \brief  Contains the various functions related to the TPS65381A object
//!
//! (C) Copyright 2015, Texas Instruments, Inc.


// **************************************************************************
// the includes

#include <math.h>


// **************************************************************************
// drivers
#include "sw/drivers/drvic/tps65381a/src/32b/f28x/f2806x/tps65381a.h"


// **************************************************************************
// modules


// **************************************************************************
// platforms


// **************************************************************************
// the defines


// **************************************************************************
// the globals


// **************************************************************************
// the function prototypes

TPS65381A_Handle TPS65381A_init(void *pMemory,const size_t numBytes)
{
  TPS65381A_Handle handle;

  if(numBytes < sizeof(TPS65381A_Obj))
    return((TPS65381A_Handle)NULL);

  // assign the handle
  handle = (TPS65381A_Handle)pMemory;

  TPS65381A_resetRxTimeout(handle);
  TPS65381A_resetEnableTimeout(handle);

  return(handle);
} // end of TPS65381A_init() function

void TPS65381A_setSpiHandle(TPS65381A_Handle handle,SPI_Handle spiHandle)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;

  // initialize the serial peripheral interface object
  obj->spiHandle = spiHandle;

  return;
} // end of TPS65381A_setSpiHandle() function


void TPS65381A_setGpioHandle(TPS65381A_Handle handle,GPIO_Handle gpioHandle)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioHandle = gpioHandle;

  return;
} // end of TPS65381A_setGpioHandle() function


void TPS65381A_setGpioSpiCsNumber(TPS65381A_Handle handle,GPIO_Number_e gpioNumber)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioSpiCsNumber = gpioNumber;

  return;
} // end of TPS65381A_setGpioSpiCsNumber() function

void TPS65381A_setGpioDiagNumber(TPS65381A_Handle handle,GPIO_Number_e gpioNumber)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioDiagNumber = gpioNumber;

  return;
} // end of TPS65381A_setGpioDiagNumber() function

void TPS65381A_setGpioWdtTrigNumber(TPS65381A_Handle handle,GPIO_Number_e gpioNumber)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;

  // initialize the gpio interface object
  obj->gpioWdtTrigNumber = gpioNumber;

  return;
} // end of TPS65381A_setGpioWdtTrigNumber() function

uint16_t TPS65381A_readSpi(TPS65381A_Handle handle,const uint16_t regAddrCmd)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;
  TPS65381A_spi_frame_t dataOut, dataIn;
  uint16_t n;

  static volatile uint16_t WaitTimeOut = 0;
  volatile SPI_FifoStatus_e RxFifoCnt = SPI_FifoStatus_Empty;

  // build the control word
  dataOut.AddrData.Addr = regAddrCmd;
  dataOut.AddrData.Data = 0x00;

  // reset the Rx fifo pointer to zero
  SPI_resetRxFifo(obj->spiHandle);
  SPI_enableRxFifo(obj->spiHandle);

  GPIO_setLow(obj->gpioHandle, obj->gpioSpiCsNumber);

  // wait for registers to update
  for(n=0;n<0x05;n++)
    asm(" NOP");

  // write the command
  SPI_write(obj->spiHandle,dataOut.frame);

  // wait for registers to send
  for(n=0;n<0x0FF;n++)
    asm(" NOP");

  // wait for the response to populate the RX fifo, else a wait timeout will occur
  while((RxFifoCnt < SPI_FifoStatus_1_Word) && (WaitTimeOut < 0xffff))
//  while((SPI_getIntFlagStatus(obj->spiHandle) == SPI_IntFlagStatus_InProgress) && (WaitTimeOut < 0xffff))
  {
    RxFifoCnt = SPI_getRxFifoStatus(obj->spiHandle);

    if(++WaitTimeOut > 0xfffe)
    {
        obj->RxTimeOut = true;
    }
  }

  // Read the word
  dataIn.frame = SPI_readEmu(obj->spiHandle);

  GPIO_setHigh(obj->gpioHandle, obj->gpioSpiCsNumber);

  return(dataIn.AddrData.Data);
} // end of TPS65381A_readSpi() function


void TPS65381A_writeSpi(TPS65381A_Handle handle,const uint16_t regAddrCmd,const uint16_t data)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;
  TPS65381A_spi_frame_t dataOut;
  uint16_t n;

  // build the control word
  dataOut.AddrData.Addr = regAddrCmd;
  dataOut.AddrData.Data = data;

  // reset the Rx fifo pointer to zero
  SPI_resetRxFifo(obj->spiHandle);
  SPI_enableRxFifo(obj->spiHandle);

  GPIO_setLow(obj->gpioHandle, obj->gpioSpiCsNumber);

  // wait for GPIO
  for(n=0;n<0x03;n++)
    asm(" NOP");

  // write the command
  SPI_write(obj->spiHandle,dataOut.frame);

  // wait for registers to update
  for(n=0;n<0x0FF;n++)
    asm(" NOP");

  GPIO_setHigh(obj->gpioHandle, obj->gpioSpiCsNumber);

  return;
}  // end of TPS65381A_writeSpi() function

void TPS65381A_setupSpi(TPS65381A_Handle handle, PMIC_SPI_65381A_Vars_t *Spi_65381a_Vars)
{
  TPS65381A_Obj *obj = (TPS65381A_Obj *)handle;
  uint16_t pmicRegAddrCmd;
  uint16_t pmicDataNew;

  // Set Default Values
  // Read/Write
  Spi_65381a_Vars->ReadCtrlCmd  = false;
  Spi_65381a_Vars->ReadStatCmd  = false;
  Spi_65381a_Vars->WriteCtrlCmd = false;
  Spi_65381a_Vars->WriteWdgCmd = false;

  // Unlock SPI WR access to listed registers
  pmicRegAddrCmd = SW_UNLOCK;
  pmicDataNew = 0x55;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  // Write SAFETY_ERR_CFG
  pmicRegAddrCmd = WR_SAFETY_ERR_CFG;
  pmicDataNew = 0x20;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,0x20);

  // Write SAFETY_CHECK_CTRL
  // Set DIAG_EXIT_MASK bit, stay in DIAGNOSTIC state (0x02)
  Spi_65381a_Vars->SAFETY_CHECK_CTRL.bit.DIAG_EXIT = 0;
  Spi_65381a_Vars->SAFETY_CHECK_CTRL.bit.DIAG_EXIT_MASK = 1;
  pmicRegAddrCmd = WR_SAFETY_CHECK_CTRL;
  pmicDataNew = Spi_65381a_Vars->SAFETY_CHECK_CTRL.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  // Read registers for default values
  // Read device DEV_REV
  pmicRegAddrCmd = RD_DEV_REV;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->DEV_REV = pmicDataNew;

  // Read device DEV_ID
  pmicRegAddrCmd = RD_DEV_ID;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->DEV_ID = pmicDataNew;

  // Read DEV_CFG1
  pmicRegAddrCmd = RD_DEV_CFG1;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->DEV_CFG1.all = pmicDataNew;

  // Read DEV_CFG2
  pmicRegAddrCmd = RD_DEV_CFG2;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->DEV_CFG2.all = pmicDataNew;

  // Read SAFETY_PWD_THR_CFG
  pmicRegAddrCmd = RD_SAFETY_PWD_THR_CFG;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_PWD_THR_CFG.all = pmicDataNew;

  // Read RD_SAFETY_CHECK_CTRL
  pmicRegAddrCmd = RD_SAFETY_CHECK_CTRL;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_CHECK_CTRL.all = pmicDataNew;

  // Read SAFETY_BIST_CTRL
  pmicRegAddrCmd = RD_SAFETY_BIST_CTRL;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_BIST_CTRL.all = pmicDataNew;

  // Read WD_WIN1_CFG
  pmicRegAddrCmd = RD_WD_WIN1_CFG;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->WD_WIN1_CFG.all = pmicDataNew;

  // Read WD_WIN2_CFG
  pmicRegAddrCmd = RD_WD_WIN2_CFG;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->WD_WIN2_CFG.all = pmicDataNew;

  // Read WD_TOKEN_VALUE
  pmicRegAddrCmd = RD_WD_TOKEN_VALUE;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->WD_TOKEN_VALUE.all = pmicDataNew;

  // Read SENS_CTRL
  pmicRegAddrCmd = RD_SENS_CTRL;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SENS_CTRL.all = pmicDataNew;

  // Read SAFETY_CFG_CRC
  pmicRegAddrCmd = RD_SAFETY_CFG_CRC;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_CFG_CRC.all = pmicDataNew;

  // Read DIAG_CFG_CTRL
  pmicRegAddrCmd = RD_DIAG_CFG_CTRL;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->DIAG_CFG_CTRL.all = pmicDataNew;

  // Read DIAG_MUX_SEL
  pmicRegAddrCmd = RD_DIAG_MUX_SEL;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->DIAG_MUX_SEL.all = pmicDataNew;

  // Read SAFETY_ERR_PWM_H
  pmicRegAddrCmd = RD_SAFETY_ERR_PWM_H;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_ERR_PWM_H.all = pmicDataNew;

  // Read SAFETY_ERR_PWM_L
  pmicRegAddrCmd = RD_SAFETY_ERR_PWM_L;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_ERR_PWM_L.all = pmicDataNew;

  // Read RD_WD_TOKEN_FDBK
  pmicRegAddrCmd = RD_WD_TOKEN_FDBK;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->WD_TOKEN_FDBK.all = pmicDataNew;

  // Read SAFETY_STAT_1
  pmicRegAddrCmd = RD_SAFETY_STAT_1;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_1.all = pmicDataNew;

  // Read SAFETY_STAT_2
  pmicRegAddrCmd = RD_SAFETY_STAT_2;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_2.all = pmicDataNew;

  // Read SAFETY_STAT_3
  pmicRegAddrCmd = RD_SAFETY_STAT_3;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_3.all = pmicDataNew;

  // Read SAFETY_STAT_4
  pmicRegAddrCmd = RD_SAFETY_STAT_4;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_4.all = pmicDataNew;

  // Read SAFETY_STAT_5
  pmicRegAddrCmd = RD_SAFETY_STAT_5;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_5.all = pmicDataNew;

  // Write SAFETY_FUNC_CFG
  // disable WD_RST_EN bit
  // Enable WD trigger mode
  Spi_65381a_Vars->SAFETY_FUNC_CFG.bit.WD_CFG = 0;
  Spi_65381a_Vars->SAFETY_FUNC_CFG.bit.WD_RST_EN = 0;
  Spi_65381a_Vars->SAFETY_FUNC_CFG.bit.DIS_NRES_MON = 0;
  pmicRegAddrCmd = WR_SAFETY_FUNC_CFG;
  pmicDataNew = Spi_65381a_Vars->SAFETY_FUNC_CFG.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  // Set WD Open/Close Time
  // open win = 7.8ms, closed win 2.6ms
  Spi_65381a_Vars->WD_WIN1_CFG.all = 0x4E;
  Spi_65381a_Vars->WD_WIN2_CFG.all = 0x1A;

  pmicRegAddrCmd = WR_WD_WIN1_CFG;
  pmicDataNew = Spi_65381a_Vars->WD_WIN1_CFG.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  pmicRegAddrCmd = WR_WD_WIN2_CFG;
  pmicDataNew = Spi_65381a_Vars->WD_WIN2_CFG.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  pmicRegAddrCmd = RD_WD_WIN1_CFG;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->WD_WIN1_CFG.all = pmicDataNew;

  pmicRegAddrCmd = RD_WD_WIN2_CFG;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->WD_WIN2_CFG.all = pmicDataNew;

  // Read SAFETY_STAT_5
  pmicRegAddrCmd = RD_SAFETY_STAT_5;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_5.all = pmicDataNew;

  // Ensure that ENDRV is disabled
  Spi_65381a_Vars->SAFETY_CHECK_CTRL.bit.ENABLE_DRV = 0;
  pmicRegAddrCmd = WR_SAFETY_CHECK_CTRL;
  pmicDataNew = Spi_65381a_Vars->SAFETY_CHECK_CTRL.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  // Clear error status registers
  Spi_65381a_Vars->SAFETY_ERR_STAT.all = 0x0000;
  pmicRegAddrCmd = WR_SAFETY_ERR_STAT;
  pmicDataNew = Spi_65381a_Vars->SAFETY_ERR_STAT.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  pmicRegAddrCmd = RD_SAFETY_ERR_STAT;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_ERR_STAT.all = pmicDataNew;

  // Read WD_FAIL_CNT in SAFETY_STAT2
  uint16_t wd_fail_cnt = 0x1F;

  GPIO_setLow(obj->gpioHandle, obj->gpioWdtTrigNumber);

  while(wd_fail_cnt >= 5)
  {
      GPIO_setLow(obj->gpioHandle, obj->gpioWdtTrigNumber);

      // Read WD_FAIL_CNT in SAFETY_STAT2
      pmicRegAddrCmd = RD_DEV_ID;
      pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
      Spi_65381a_Vars->SAFETY_STAT_2.all = TPS65381A_readSpi(handle,RD_SAFETY_STAT_2);
      wd_fail_cnt = Spi_65381a_Vars->SAFETY_STAT_2.bit.WD_FAIL_CNT;

      GPIO_setHigh(obj->gpioHandle, obj->gpioWdtTrigNumber);
  }

  GPIO_setHigh(obj->gpioHandle, obj->gpioWdtTrigNumber);

  // Write SAFETY_FUNC_CFG
  // Enable WD_RST_EN bit
  // Enable WD trigger mode
  Spi_65381a_Vars->SAFETY_FUNC_CFG.bit.WD_RST_EN = 1;
  pmicRegAddrCmd = RD_DEV_ID;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  TPS65381A_writeSpi(handle,WR_SAFETY_FUNC_CFG,
                     Spi_65381a_Vars->SAFETY_FUNC_CFG.all);

  // Write SAFETY_CHECK_CTRL
  // Set DIAG_EXIT bit
  // Clear DIAG_EXIT_MASK bit
  Spi_65381a_Vars->SAFETY_CHECK_CTRL.bit.DIAG_EXIT_MASK = 0;
  Spi_65381a_Vars->SAFETY_CHECK_CTRL.bit.DIAG_EXIT = 1;
  pmicRegAddrCmd = WR_SAFETY_CHECK_CTRL;
  pmicDataNew = Spi_65381a_Vars->SAFETY_CHECK_CTRL.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  wd_fail_cnt = 0x1F;

  while(wd_fail_cnt >= 5)
  {
      // Read WD_FAIL_CNT in SAFETY_STAT2
      pmicRegAddrCmd = RD_SAFETY_STAT_2;
      pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
      Spi_65381a_Vars->SAFETY_STAT_2.all = pmicDataNew;
      wd_fail_cnt = Spi_65381a_Vars->SAFETY_STAT_2.bit.WD_FAIL_CNT;
  }

  // Write SAFETY_CHECK_CTRL
  Spi_65381a_Vars->SAFETY_CHECK_CTRL.bit.ENABLE_DRV = 1;
  pmicRegAddrCmd = WR_SAFETY_CHECK_CTRL;
  pmicDataNew = Spi_65381a_Vars->SAFETY_CHECK_CTRL.all;
  TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

  // Read SAFETY_STAT_2
  pmicRegAddrCmd = RD_SAFETY_STAT_2;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_2.all = pmicDataNew;

  // Read SAFETY_STAT_4
  pmicRegAddrCmd = RD_SAFETY_STAT_4;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_4.all = pmicDataNew;

  // Read SAFETY_STAT_5
  pmicRegAddrCmd = RD_SAFETY_STAT_5;
  pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
  Spi_65381a_Vars->SAFETY_STAT_5.all = pmicDataNew;

  return;
} // end of TPS65381A_setupSpi() function


void TPS65381A_writeCtrlData(TPS65381A_Handle handle, PMIC_SPI_65381A_Vars_t *Spi_65381a_Vars)
{
  uint16_t pmicRegAddrCmd;
  uint16_t pmicDataNew;

  if(Spi_65381a_Vars->WriteCtrlCmd)
  {
    // Unlock SPI WR access to listed registers
    pmicRegAddrCmd = SW_UNLOCK;
    pmicDataNew = 0x55;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Write SAFETY_ERR_CFG
    pmicRegAddrCmd = WR_SAFETY_ERR_CFG;
    pmicDataNew = 0x20;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Write DEV_CFG1
    pmicRegAddrCmd = WR_DEV_CFG1;
    pmicDataNew = Spi_65381a_Vars->DEV_CFG1.all;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Write DEV_CFG2
    pmicRegAddrCmd = WR_DEV_CFG2;
    pmicDataNew = Spi_65381a_Vars->DEV_CFG2.all;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Write SAFETY_PWD_THR_CFG
    pmicRegAddrCmd = WR_SAFETY_PWD_THR_CFG;
    pmicDataNew = Spi_65381a_Vars->SAFETY_PWD_THR_CFG.all;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Write SAFETY_BIST_CTRL
    pmicRegAddrCmd = WR_SAFETY_CHECK_CTRL;
    pmicDataNew = Spi_65381a_Vars->SAFETY_BIST_CTRL.all;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Write SENS_CTRL
    pmicRegAddrCmd = WR_SENS_CTRL;
    pmicDataNew = Spi_65381a_Vars->SENS_CTRL.all;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Lock SPI WR access to listed registers
    pmicRegAddrCmd = SW_LOCK;
    pmicDataNew = 0xAA;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    Spi_65381a_Vars->WriteCtrlCmd = false;
  }

  return;
}  // end of TPS65381A_writeCtrlData() function

void TPS65381A_writeWdgData(TPS65381A_Handle handle, PMIC_SPI_65381A_Vars_t *Spi_65381a_Vars)
{
  uint16_t pmicRegAddrCmd;
  uint16_t pmicDataNew;

  if(Spi_65381a_Vars->WriteWdgCmd)
  {
    // Write WD_WIN1_CFG
    pmicRegAddrCmd = WR_WD_WIN1_CFG;
    pmicDataNew = Spi_65381a_Vars->WD_WIN1_CFG.all;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    // Write WD_WIN2_CFG
    pmicRegAddrCmd = WR_WD_WIN2_CFG;
    pmicDataNew = Spi_65381a_Vars->WD_WIN2_CFG.all;
    TPS65381A_writeSpi(handle,pmicRegAddrCmd,pmicDataNew);

    Spi_65381a_Vars->WriteWdgCmd = false;
  }

  return;
}  // end of TPS65381A_writeWdgData() function

void TPS65381A_readStatData(TPS65381A_Handle handle, PMIC_SPI_65381A_Vars_t *Spi_65381a_Vars)
{
  uint16_t pmicRegAddrCmd;
  uint16_t pmicDataNew;

  if(Spi_65381a_Vars->ReadStatCmd)
  {
    // Read Status Register SAFETY_STAT_1
    pmicRegAddrCmd = RD_SAFETY_STAT_1;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_STAT_1.all = pmicDataNew;

    // Read Status Register SAFETY_STAT_2
    pmicRegAddrCmd = RD_SAFETY_STAT_2;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_STAT_2.all = pmicDataNew;

    // Read Status Register SAFETY_STAT_3
    pmicRegAddrCmd = RD_SAFETY_STAT_3;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_STAT_3.all = pmicDataNew;

    // Read Status Register SAFETY_STAT_4
    pmicRegAddrCmd = RD_SAFETY_STAT_4;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_STAT_4.all = pmicDataNew;

    // Read Status Register SAFETY_STAT_5
    pmicRegAddrCmd = RD_SAFETY_STAT_5;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_STAT_5.all = pmicDataNew;

    // Read Status Register SAFETY_ERR_STAT
    pmicRegAddrCmd = RD_SAFETY_ERR_STAT;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_ERR_STAT.all = pmicDataNew;

    // Read Status Register VMON_STAT_1
    pmicRegAddrCmd = RD_VMON_STAT_1;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->VMON_STAT_1.all = pmicDataNew;

    // Read Status Register VMON_STAT_2
    pmicRegAddrCmd = RD_SAFETY_STAT_5;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->VMON_STAT_2.all = pmicDataNew;

    Spi_65381a_Vars->ReadStatCmd = false;
  }

    return;
}  // end of TPS65381A_readStatData() function

void TPS65381A_readCtrlData(TPS65381A_Handle handle, PMIC_SPI_65381A_Vars_t *Spi_65381a_Vars)
{
  uint16_t pmicRegAddrCmd;
  uint16_t pmicDataNew;

  if(Spi_65381a_Vars->ReadCtrlCmd)
  {
    // Read DEV_CFG1
    pmicRegAddrCmd = RD_DEV_CFG1;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->DEV_CFG1.all = pmicDataNew;

    // Read DEV_CFG2
    pmicRegAddrCmd = RD_DEV_CFG2;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->DEV_CFG2.all = pmicDataNew;

    // Read SAFETY_ERR_CFG
    pmicRegAddrCmd = RD_SAFETY_ERR_CFG;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_ERR_CFG.all = pmicDataNew;

    // Read SAFETY_ERR_STAT
    pmicRegAddrCmd = RD_SAFETY_ERR_STAT;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_ERR_STAT.all = pmicDataNew;

    // Read SAFETY_PWD_THR_CFG
    pmicRegAddrCmd = RD_SAFETY_PWD_THR_CFG;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_PWD_THR_CFG.all = pmicDataNew;

    // Read SAFETY_CHECK_CTRL
    pmicRegAddrCmd = RD_SAFETY_CHECK_CTRL;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_CHECK_CTRL.all = pmicDataNew;

    // Read SAFETY_BIST_CTRL
    pmicRegAddrCmd = RD_SAFETY_CHECK_CTRL;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_BIST_CTRL.all = pmicDataNew;

    // Read SAFETY_FUNC_CFG
    pmicRegAddrCmd = RD_SAFETY_FUNC_CFG;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SAFETY_FUNC_CFG.all = pmicDataNew;

    // Read SENS_CTRL
    pmicRegAddrCmd = RD_SENS_CTRL;
    pmicDataNew = TPS65381A_readSpi(handle,pmicRegAddrCmd);
    Spi_65381a_Vars->SENS_CTRL.all = pmicDataNew;

    Spi_65381a_Vars->ReadCtrlCmd = false;
  }

  return;
}  // end of TPS65381A_readCtrlData() function


// end of file
