// documentation page
//!
//!
//! \defgroup CLARKE_OVERVIEW Module overview
//@{
//! \page clarke Clarke (CLARKE) Transform Module
//!
//! \section description Description
//!
//! This module performs the Clarke transformation, which translates a vector represented in a 
//! three phase coordinate system (a,b,c) into a vector represented in a two phase
//! orthogonal reference frame (\f$ \alpha,\beta \f$).  The following figure shows the coordinate
//! transformation of a general vector x, which can be expressed in either coordinate system.
//! \image html clarke.jpg 
//!
//! The Clarke transform can be described mathematically as follows: \n
//!
//! \f[ x_{\alpha} =  \frac{2}{3}x_{a} - \frac{1}{3}(x_{b}+x_{c}) \f]
//! \f[ x_{\beta} = \frac{1}{\sqrt{3}}(x_{b} - x_{c}) \f]
//! \n
//! where \n\n
//! \f$ x_{\alpha} \f$ is the projection of the original vector in the \f$ X_{\alpha} \f$ direction \n
//! \f$ x_{\beta} \f$ is the projection of the original vector in the \f$ X_{\beta} \f$ direction \n
//! \f$ x_{a} \f$ is the projection of the original vector in the \f$ X_{a} \f$ direction \n
//! \f$ x_{b} \f$ is the projection of the original vector in the \f$ X_{b} \f$ direction \n
//! \f$ x_{c} \f$ is the projection of the original vector in the \f$ X_{c} \f$ direction \n
//!
//! \n
//! Please see the CLARKE_init(), CLARKE_setup() and CLARKE_run() functions define in \ref clarke.h for more details.
//!
//! \section integration Integration Information
//!
//! There is only one module in this package, the APIs can be referenced at
//! \ref CLARKE. The API headers can be located at \ref clarke.h.
//! The test procedures are described at test_clarke.h.
//! 
//! \section reference References
//!
//!
//!
//@}
