/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//! \file   modules/clarke/test/src/test_clarke.c
//! \brief  Portable C fixed point code.  These functions define the 
//!         Clarke transform module routines
//!
//! (C) Copyright 2012, Texas Instruments, Inc.


// **************************************************************************
// the includes


// drivers

// This file includes the device-specific includes. It is located in the
// ccs project directory (e.g. modules/<module>/test/f28x/f2806xF/test_<module>/projects/ccs5
#include "driver_headers.h"


// modules
#include "sw/modules/math/src/32b/math.h"
#include "sw/modules/clarke/src/32b/clarke.h"

#include "sw/modules/clarke/test/src/test_clarke.h"


// boards


#pragma CODE_SECTION(main,"ramfuncs");


// **************************************************************************
// the defines


// **************************************************************************
// the globals

uint_least8_t gNumSensors;

_iq gIn_1,gIn_2,gIn_3;
_iq gAlpha,gBeta;
_iq gOut_1,gOut_2;

CLARKE_Obj    clarke;
CLARKE_Handle clarkeHandle;

WDOG_Obj      wdog;
WDOG_Handle   wdogHandle;


volatile bool   gFlag_waitForHostToWriteInputData = false;
volatile bool   gFlag_waitForHostToReadOutputData = false;


// **************************************************************************
// the functions

void main(void)
{
  MATH_vec3 inVec;
  MATH_vec2 outVec;

  // initialize the watchdog driver
  wdogHandle = WDOG_init((void *)WDOG_BASE_ADDR,sizeof(WDOG_Obj));

  // disable the watchdog 
  WDOG_disable(wdogHandle);

  // initialize the Clarke module
  clarkeHandle = CLARKE_init(&clarke,sizeof(CLARKE_Obj));

  // set flag
  gFlag_waitForHostToWriteInputData = true;

  // wait for the host to write input data
  while(gFlag_waitForHostToWriteInputData);

  // set the number of sensors
  CLARKE_setNumSensors(clarkeHandle,gNumSensors);

  // set the scale factors
  CLARKE_setScaleFactors(clarkeHandle,gAlpha,gBeta);

  // initialize the input vector
  inVec.value[0] = gIn_1;
  inVec.value[1] = gIn_2;
  inVec.value[2] = gIn_3;

  // run the clarke transform
  CLARKE_run(clarkeHandle,&inVec,&outVec);

  // set the global variables
  gOut_1 = outVec.value[0];
  gOut_2 = outVec.value[1];

  // set flag
  gFlag_waitForHostToReadOutputData = true;

  // wait for host to read output data
  while(gFlag_waitForHostToReadOutputData);

} // end of main() function

// end of file


