// This is a little header file which doxygen parses to generate the main
// documentation page
//!
//! \defgroup IPARK_OVERVIEW Module overview
//@{
//!
//! \page ipark Inverse Park (IPARK) Transform Module
//!
//! \section description Description
//!
//! This module performs the inverse Park transformation, which translates a vector represented in a 
//! rotated two phase orthogonal coordinate system (d,q) into a vector represented in a two phase
//! orthogonal reference frame (\f$ \alpha,\beta \f$).  The following figure shows the coordinate
//! transformation of a general vector x, which can be expressed in either coordinate system.
//! \image html ipark.jpg 
//!
//! The inverse Park transform can be described mathematically as follows: \n
//!
//! \f[ x_{\alpha} =  x_{d}cos(\theta) - x_{q}sin(\theta) \f]
//! \f[ x_{\beta} = x_{d}sin(\theta) + x_{q}cos(\theta) \f]
//! \n
//! where \n\n
//! \f$ \theta \f$ is the angle between the two coordinate systems \n
//! \f$ x_{\alpha} \f$ is the projection of the original vector in the \f$ X_{\alpha} \f$ direction \n
//! \f$ x_{\beta} \f$ is the projection of the original vector in the \f$ X_{\beta} \f$ direction \n
//! \f$ x_{d} \f$ is the projection of the original vector in the \f$ X_{d} \f$ direction \n
//! \f$ x_{q} \f$ is the projection of the original vector in the \f$ X_{q} \f$ direction \n
//! \f$ sin() \f$ is a sine function \n
//! \f$ cos() \f$ is a cosine function \n
//!
//! \n
//! Please see the IPARK_init(), IPARK_setup() and IPARK_run() functions define in \ref ipark.h for more details.
//!
//!
//! \section integration Integration Information
//!
//! There is only one module in this package, the APIs can be referenced at
//! \ref IPARK. The API headers can be located at \ref ipark.h.
//! The test procedures are described at test_ipark.h.
//! 
//! \section reference References
//!
//@}
