//! \file   modules/ipark/test/src/test_ipark.c
//! \brief  The functions in this file are used to test the
//!         inverse Park transform routines
//!
//! (C) Copyright 2012, Texas Instruments, Inc.


// **************************************************************************
// the includes


// drivers

// This file includes the device-specific includes. It is located in the
// ccs project directory (e.g. modules/<module>/test/f28x/f2806xF/test_<module>/projects/ccs5
#include "driver_headers.h"


// modules
#include "sw/modules/math/src/32b/math.h"
#include "sw/modules/ipark/src/32b/ipark.h"

#include "sw/modules/ipark/test/src/test_ipark.h"


// boards


#pragma CODE_SECTION(main,"ramfuncs");


// **************************************************************************
// the defines


// **************************************************************************
// the globals

_iq gCosTh,gSinTh;
_iq gIn_1,gIn_2;
_iq gOut_1,gOut_2;

IPARK_Obj    ipark;
IPARK_Handle iparkHandle;

WDOG_Obj      wdog;
WDOG_Handle   wdogHandle;

volatile bool   gFlag_waitForHostToWriteInputData = false;
volatile bool   gFlag_waitForHostToReadOutputData = false;


// **************************************************************************
// the functions

void main(void)
{
  MATH_vec2 inVec;
  MATH_vec2 phasor;
  MATH_vec2 outVec;

  // initialize the watchdog driver
  wdogHandle = WDOG_init((void *)WDOG_BASE_ADDR,sizeof(WDOG_Obj));

  // disable the watchdog 
  WDOG_disable(wdogHandle);

  // initialize the inverse Park module
  iparkHandle = IPARK_init(&ipark,sizeof(IPARK_Obj));

  // set flag
  gFlag_waitForHostToWriteInputData = true;

  // wait for the host to write input data
  while(gFlag_waitForHostToWriteInputData);

  // set the phasor
  phasor.value[0] = gCosTh;
  phasor.value[1] = gSinTh;
  IPARK_setPhasor(iparkHandle,&phasor);

  // initialize the input vector
  inVec.value[0] = gIn_1;
  inVec.value[1] = gIn_2;

  // run the inverse Park transform
  IPARK_run(iparkHandle,&inVec,&outVec);

  // set the global variables
  gOut_1 = outVec.value[0];
  gOut_2 = outVec.value[1];

  // set flag
  gFlag_waitForHostToReadOutputData = true;

  // wait for host to read output data
  while(gFlag_waitForHostToReadOutputData);

} // end of main() function

// end of file


