//! \file   modules/math/test/f28x/f2803x/test/src/test_math.c
//! \brief  The functions in this file are used to test the
//!         math routines
//!
//! (C) Copyright 2011, Texas Instruments, Inc.


// **************************************************************************
// the includes

// system includes


// drivers
#include "sw/drivers/src/f28x/f2803x/timer.h"


// modules
#include "sw/modules/math/src/32b/math.h"
#include "test_math.h"


// boards


#pragma CODE_SECTION(main,"ramfuncs");
#pragma CODE_SECTION(checkErrorValues,"ramfuncs");
#pragma CODE_SECTION(initTestValues,"ramfuncs");


// **************************************************************************
// the defines


// **************************************************************************
// the globals

int_least32_t gDelta_c=0,gDelta_macro=0;


MATH_vec2  gInputValues[NUM_TEST_VALUES];
MATH_vec2  gErrorValues[NUM_TEST_VALUES];

bool   gStatus=OK;
bool   gBeginFlag=false;
bool   gEndFlag=false;


// **************************************************************************
// the functions

void main(void)
{
  uint_least8_t numSensors;
  uint_least32_t valueCnt;
  float          freq_MHz,period_usec;
  _iq          scaleFactor_alpha;
  _iq          scaleFactor_beta;


  // set tetst start flag
  gBeginFlag = true;


  // initialize the test data
  initTestValues(&gInputValues[0],NUM_TEST_VALUES);


  // initialize the cpu timers
  InitCpuTimers();


  // initialize the cpu timers
  freq_MHz = 60;
  period_usec = 1000000;
  ConfigCpuTimer(&CpuTimer0,freq_MHz,period_usec);



  // initialize the module


  // start the timer
  StartCpuTimer0();


  // compute the cycles for the PID function
  for(valueCnt=0;valueCnt<NUM_TEST_VALUES;valueCnt++)
    {
      volatile int32_t cnt_1;
      volatile int32_t cnt_2;
      MATH_vec2 outValue;

      // read the timer value
      cnt_1 = ReadCpuTimer0Counter();

      // run the c code

      // read the timer value
      cnt_2 = ReadCpuTimer0Counter();

      // compute the delta counts
      gDelta_c += cnt_1 - cnt_2 + 1;
    } // end of valueCnt for loop

} // end of main() function


bool checkErrorValues(const MATH_vec2 *pErrorValues,const int_least32_t numValues)
{
  uint_least32_t  valueCnt;
  bool          status = OK;


  for(valueCnt=0;valueCnt<numValues;valueCnt++)
    {
      // check the first value
      if(pErrorValues[valueCnt].value[0] != _IQ(0.0))
        {
          status = ERROR;
        } // end of if loop

      // check the second value
      if(pErrorValues[valueCnt].value[1] != _IQ(0.0))
        {
          status = ERROR;
        } // end of if loop
    } // end of valueCnt for loop

  return(status);
} // end of checkError() function


void initTestValues(MATH_vec2 *pInputValues,uint_least32_t numValues)
{
  uint_least32_t  valueCnt;

  for(valueCnt=0;valueCnt<numValues;valueCnt++)
    {
      pInputValues[valueCnt].value[0] = _IQ(2.13) * _IQ(valueCnt);
      pInputValues[valueCnt].value[1] = _IQ(-1.54) * _IQ(valueCnt);
    } // end of valueCnt for loop

  return;
} // end of initTestValues() function

// end of file


