//! \file   modules/offset/test/f28x/f2806x/test/projects/ccs5/test_offsets/test_offsets.c
//! \brief  The functions in this file are used to test the
//!         estimator routines
//!
//! (C) Copyright 2011, Texas Instruments, Inc.


// **************************************************************************
// the includes

// system includes
//#include <math.h>

// Include header files used in the main function


// modules
#include "sw/modules/math/src/32b/math.h"
#include "sw/modules/offset/src/32b/offset.h"
#include "sw/modules/iqmath/src/32b/IQmathLib.h"


// drivers


// platforms
#include "sw/modules/offset/f28x/f2806x/test/src/hal.h"
#include "test_offsets.h"



// **************************************************************************
// the defines
#define CLK_FREQUENCY_Hz (80.0e6)
#define SAMPLE_FREQUENCY_Hz (10.0e3)
#define USER_VOLTAGE_FILTER_POLE_Hz (335.648)
#define USER_VOLTAGE_FILTER_POLE_rps (2 * MATH_PI * USER_VOLTAGE_FILTER_POLE_Hz)
#define BETA (USER_VOLTAGE_FILTER_POLE_rps/SAMPLE_FREQUENCY_Hz)

#define TIMER_PRD CLK_FREQUENCY_Hz/SAMPLE_FREQUENCY_Hz
// **************************************************************************
// the globals

HAL_Handle halHandle;

OFFSET_Obj IVoffset[6];
OFFSET_Handle IVoffsetHandle[6];

_iq ADCvalues[6] = {_IQ(0.1), _IQ(-0.1), _IQ(0.2), _IQ(-0.3), _IQ(0.95), _IQ(-0.855)};
_iq ADCoffset[6];


// **************************************************************************
// the functions

void main(void)
{

  // initialize the hardware abstraction layer
  halHandle = HAL_init(&hal,sizeof(hal));


  // setup the hardware abstraction layer
  HAL_setup(halHandle);


  // initialize the interrupt vector table
  HAL_initIntVectorTable(halHandle);

  // initialize the offset calculator
  {
    int n;
    for(n=0; n<6; n++)
    {
      IVoffsetHandle[n] = OFFSET_init(&IVoffset[n],sizeof(IVoffset[n]));
      OFFSET_setBeta(IVoffsetHandle[n], _IQ(BETA));
    }
  }

  // setup the Timer0
  HAL_setupTimer(halHandle, (uint32_t) TIMER_PRD);


  // enable Timer0 interrupt
  HAL_enableTimerInt(halHandle);


  // enable global interrupts
  HAL_enableGlobalInts(halHandle);


  // enable debug interrupts
  HAL_enableDebugInt(halHandle);


  // Waiting for enable system flag to be set
  while(1)
    { 
    }

} // end of main() function


interrupt void mainISR(void)
{
  uint16_t n;

  // DPM - turn on LED 3 on the card
  HAL_turnLedOn(halHandle,(GPIO_Number_e)HAL_Gpio_LEDstatus);


  // acknowledge the Timer0 interrupt
  HAL_acqTimer0Int(halHandle);


  // Find the offset of the inputs
  for(n=0; n<6; n++)
  {
	OFFSET_run_measure(IVoffsetHandle[n], ADCvalues[n]);
	ADCoffset[n] = OFFSET_getOffset(IVoffsetHandle[n]);
  }

  // DPM - turn off LED 3 on the card
  HAL_turnLedOff(halHandle,(GPIO_Number_e)HAL_Gpio_LEDstatus);

  return;
} // end of mainISR() function
