// documentation page
//!
//!
//! \defgroup PARK_OVERVIEW Module overview
//@{
//! \page park Park (PARK) Transform Module
//!
//! \section description Description
//!
//! This module performs the inverse Park transformation, which translates a vector in a two phase
//! orthogonal reference frame (\f$ \alpha,\beta \f$) into a rotated two phase orthogonal 
//! coordinate system (d,q).  The following figure shows the coordinate
//! transformation of a general vector x, which can be expressed in either coordinate system.
//! \image html park.jpg 
//!
//! The Park transform can be described mathematically as follows: \n
//!
//! \f[ x_{\alpha} =  x_{d}cos(\theta) + x_{q}sin(\theta) \f]
//! \f[ x_{\beta} = -x_{d}sin(\theta) + x_{q}cos(\theta) \f]
//! \n
//! where \n\n
//! \f$ \theta \f$ is the angle between the two coordinate systems \n
//! \f$ x_{\alpha} \f$ is the projection of the original vector in the \f$ X_{\alpha} \f$ direction \n
//! \f$ x_{\beta} \f$ is the projection of the original vector in the \f$ X_{\beta} \f$ direction \n
//! \f$ x_{d} \f$ is the projection of the original vector in the \f$ X_{d} \f$ direction \n
//! \f$ x_{q} \f$ is the projection of the original vector in the \f$ X_{q} \f$ direction \n
//! \f$ sin() \f$ is a sine function \n
//! \f$ cos() \f$ is a cosine function \n
//!
//! \n
//! Please see the PARK_init(), PARK_setup() and PARK_run() functions define in \ref park.h for more details.
//!
//!
//! \section integration Integration Information
//!
//! There is only one module in this package, the APIs can be referenced at
//! \ref PARK. The API headers can be located at \ref park.h.
//! The test procedures are described at test_park.h.
//! 
//! \section reference References
//!
//!
//@}
