// documentation page
//!
//!
//! \defgroup PID_OVERVIEW Module overview
//@{
//! \page pid Proportional-Integral-Derivative (PID) Module
//!
//! \section description Description
//!
//!
//! The original code for this module documented in ControlSUITE implements 
//! a 32-bit digital PID controller with anti-windup correction. The following
//! implementation of the PID documented here are modified versions of the
//! original ControlSUITE implementation. The changes concern removal
//! of the D-action since it was not required for motor control, and a more
//! predictable clipping behaviour. Instead of a integral correction gain, 
//! hard clipping is implemented on the integrator output as well as the final
//! output.\n\n
//! The first function implemented in the \ref PID module is the PID_run().
//! Two outputs are generated, and proportional and integral gains combined
//! as shown in the following equations:\n\n
//! \f[ U_p(k) = e(k)\cdot K_p \f]
//! \f[ U_i(k) = Sat\Big(U_i(k-1)+e(k)\cdot K_p\cdot K_i\Big) \f]
//! \f[ U(k) = Sat\Big(U_p(k)+U_i(k)\Big) \f]
//! \n The second function implemented in the \ref PID module is the PID_run_spd().
//! Two outputs are added together, and proportional and integral gains are
//! independent of each other as shown in the following equations:\n\n
//! \f[ U_p(k) = e(k)\cdot K_p \f]
//! \f[ U_i(k) = Sat\Big(U_i(k-1)+e(k)\cdot K_i\Big) \f]
//! \f[ U(k) = Sat\Big(U_p(k)+U_i(k)\Big) \f]
//! \section simulation Simulation Information
//! The following figure shows a top level simulation model in Simulink.\n\n
//! \image html SimulinkModel.jpg
//! The following figures show implementation of each of these two PID models.
//! \image html SimulinkPID.jpg
//! \image html SimulinkPIDmech.jpg
//! The following figure shows the error in the calculation by the microcontroller,
//! and compares it agains simulation output from Simulink.\n
//! \f$\bullet\f$ Error is the microcontroller output minus Simulink output for function PID_run().\n
//! \f$\bullet\f$ Error Mech is the error for function PID_run_spd().\n
//! \f$\bullet\f$ Outputs shows both microcontroller and Simulink outputs for PID_run().\n
//! \f$\bullet\f$ Outputs Mech shows outputs for PID_run_spd().\n
//! \image html SimOutput.jpg
//! \section configuration Configuration Information
//! The modules in this package require several parameters that must be
//! initialized before the main PID module will function properly. Please see
//! the PID_init(), PID_setup(), PID_run() and PID_run_spd() functions
//! defined in \ref pid.h for more details.
//!
//!
//! \section integration Integration Information
//!
//! There is only one module in this package, the APIs can be referenced at
//! \ref PID.  The module headers are located at \ref pid.h.
//! The test procedures are described at test_pid.h.
//! 
//! \section reference References
//! 1.	ControlSUITE Documentation for \ref PID Module. 
//!
//!
//!
//@}
