//! \file   modules/pid/test/src/test_pid.c
//! \brief  The functions in this file are used to test the
//!         Proportional-Integral-Derivative (PID) controller routines
//!
//! (C) Copyright 2012, Texas Instruments, Inc.


// **************************************************************************
// the includes


// drivers

// This file includes the device-specific includes. It is located in the
// ccs project directory (e.g. modules/<module>/test/f28x/f2806xF/test_<module>/projects/ccs5
#include "driver_headers.h"


// modules
#include "sw/modules/math/src/32b/math.h"
#include "sw/modules/pid/src/32b/pid.h"

#include "sw/modules/pid/test/src/test_pid.h"


// boards


#pragma CODE_SECTION(main,"ramfuncs");


// **************************************************************************
// the defines


// **************************************************************************
// the globals

_iq gKp,gKi,gKd;
_iq gOutMin,gOutMax;
_iq gUi;
_iq gRefValue,gFbackValue;
_iq gOut;

PID_Obj    pid;
PID_Handle pidHandle;

WDOG_Obj      wdog;
WDOG_Handle   wdogHandle;

volatile bool   gFlag_waitForHostToWriteInputData = false;
volatile bool   gFlag_waitForHostToReadOutputData = false;


// **************************************************************************
// the functions

void main(void)
{
  // initialize the watchdog driver
  wdogHandle = WDOG_init((void *)WDOG_BASE_ADDR,sizeof(WDOG_Obj));

  // disable the watchdog 
  WDOG_disable(wdogHandle);

  // initialize the PID module
  pidHandle = PID_init(&pid,sizeof(PID_Obj));

  // set flag
  gFlag_waitForHostToWriteInputData = true;

  // wait for the host to write input data
  while(gFlag_waitForHostToWriteInputData);

  // set the gain values
  PID_setGains(pidHandle,gKp,gKi,gKd);

  // set the output minimum and maximum values
  PID_setMinMax(pidHandle,gOutMin,gOutMax);

  // set the integrator start value
  PID_setUi(pidHandle,gUi);

  // run the PID controller
  PID_run(pidHandle,gRefValue,gFbackValue,&gOut);

  // set flag
  gFlag_waitForHostToReadOutputData = true;

  // wait for host to read output data
  while(gFlag_waitForHostToReadOutputData);

} // end of main() function

// end of file


