//! \file   modules/svgen/test/src/test_svgen.c
//! \brief  The functions in this file are used to test the
//!         Space Vector Generator (SVGEN) transform routines
//!
//! (C) Copyright 2012, Texas Instruments, Inc.


// **************************************************************************
// the includes


// drivers

// This file includes the device-specific includes. It is located in the
// ccs project directory (e.g. modules/<module>/test/f28x/f2806xF/test_<module>/projects/ccs5
#include "driver_headers.h"


// modules
#include "sw/modules/math/src/32b/math.h"
#include "sw/modules/svgen/src/32b/svgen.h"

#include "sw/modules/svgen/test/src/test_svgen.h"


// boards


#pragma CODE_SECTION(main,"ramfuncs");


// **************************************************************************
// the defines


// **************************************************************************
// the globals

_iq gMaxModulation;
_iq gIn_1,gIn_2;
_iq gOut_1,gOut_2,gOut_3;

WDOG_Obj      wdog;
WDOG_Handle   wdogHandle;

SVGEN_Obj    svgen;
SVGEN_Handle svgenHandle;

volatile bool   gFlag_waitForHostToWriteInputData = false;
volatile bool   gFlag_waitForHostToReadOutputData = false;


// **************************************************************************
// the functions

void main(void)
{
  MATH_vec2 inVec;
  MATH_vec3 outVec;

  // initialize the watchdog driver
  wdogHandle = WDOG_init((void *)WDOG_BASE_ADDR,sizeof(WDOG_Obj));

  // disable the watchdog 
  WDOG_disable(wdogHandle);

  // initialize the space vector generator module
  svgenHandle = SVGEN_init(&svgen,sizeof(SVGEN_Obj));

  // set flag
  gFlag_waitForHostToWriteInputData = true;

  // wait for the host to write input data
  while(gFlag_waitForHostToWriteInputData);

  // set the maximum modulation
  SVGEN_setMaxModulation(svgenHandle,gMaxModulation);

  // initialize the input vector
  inVec.value[0] = gIn_1;
  inVec.value[1] = gIn_2;

  // run the space vector generator module
  SVGEN_run(svgenHandle,&inVec,&outVec);

  // set the global variables
  gOut_1 = outVec.value[0];
  gOut_2 = outVec.value[1];
  gOut_3 = outVec.value[2];

  // set flag
  gFlag_waitForHostToReadOutputData = true;

  // wait for host to read output data
  while(gFlag_waitForHostToReadOutputData);

} // end of main() function

// end of file


