// documentation page
//!
//!
//! \defgroup TRAJ_OVERVIEW Module overview
//@{
//! \page traj Trajectory (TRAJ) Module
//!
//! \section description Description
//!
//!
//! \subsection overview Package overview
//!
//! 
//! In this implementation the frequency of the ramp output is controlled by a precision frequency 
//! generation algorithm which relies on the modulo nature (i.e. wrap-around) of finite length variables
//! in 28xx. One such variable, called \f$StepAngleMax\f$ (a data memory location in 28xx) in this implementation,
//! is used as a variable to determine the minimum \f$ period = \frac{1}{Freq} \f$ of the ramp signal. Adding a fixed
//! step value to the Angle variable causes the value in Angle to cycle at a constant rate.
//! \f[ Angle = Angle + StepAngleMax\cdot Freq \f]
//! At the end limit the value in \f$Angle\f$ simply wraps around and continues at the next modulo value given by
//! the step size. For a given step size, the frequency of the ramp output (in Hz) is given by:
//! \f[ f = \frac{StepAngle\cdot f_s}{2^m} \f]
//! where \n\n
//! \f$ f_s \f$ is the sampling loop frequency in Hz \n
//! \f$ m \f$ is the number of bits in the auto wrapper variable \f$Angle\f$
//! \n \n \n
//! From the above equation it is clear that a \f$StepAngle\f$ value of 1 gives: \f$f = 0.3052 Hz\f$ when \f$m = 16\f$ and 
//! \f$ f_s = 20 kHz \f$.
//! \n
//! For IQmath implementation, the maximum step size in per-unit, \f$StepAngleMax\f$, for a given base frequency, 
//! \f$f_b\f$ and a defined \f$GLOBAL\_Q\f$ number is therefore computed as follows:\n\n
//! \f[ StepAngleMax = f_b\cdot T_s\cdot 2^{GLOBAL\_Q} \f]
//! \n
//! Equivalently, by using _IQ() function for converting from a floating-point number to a _iq number, the 
//! \f$StepAngleMax\f$ can also be computed as:\n\n
//! \f[ StepAngleMax = \_IQ(f_b\cdot T_s) \f]
//! \n
//! where \f$T_s\f$ is the sampling period in seconds.
//! \n\n\n
//! \section simulation Simulation Information
//! The following figure shows the Simulink Model of this block.
//! \image html SimulinkModel.jpg
//! The following figure shows the error in the calculation by the microcontroller,
//! and compares it agains simulation output from Simulink.\n
//! \f$\bullet\f$ Error is the microcontroller output minus Simulink output for function RAMPGEN_run().\n
//! \f$\bullet\f$ Outputs shows both microcontroller and Simulink outputs for RAMPGEN_run().\n
//! \image html SimOutput.jpg
//! \section configuration Configuration Information
//!
//! \n
//! Please see the TRAJ_init() and TRAJ_run() functions defined in \ref traj.h for more details.
//! \n\n
//! \section integration Integration Information
//!
//! There is only one module in this package, the APIs can be referenced at
//! \ref TRAJ. The API headers can be located at \ref traj.h.
//! The test procedures are described at test_traj.h.
//! 
//! \section reference References
//! 1.	ControlSUITE Documentation for \ref TRAJ Module. 
//!
//!
//!
//@}
