//----------------------------------------------------------------------------------
//	FILE:			drv8305.c
//
//	Description:	Contains DRV8305 interface functions
//
//	Version: 		1.0
//
//  Target:  		TMS320F28377S
//
//----------------------------------------------------------------------------------
//  Copyright Texas Instruments 2004-2015
//----------------------------------------------------------------------------------
//  Revision History:
//----------------------------------------------------------------------------------
//  Date	  | Description / Status
//----------------------------------------------------------------------------------
// 4 Nov 2015 - DRV8305 interface functions
//----------------------------------------------------------------------------------
#include "F2806x_Device.h"     // F2806x Headerfile Include File

#include "sw/modules/types/src/types.h"
#include "sw/modules/usDelay/src/32b/usDelay.h"

#include "sw/safety/drv8305q1/src/32b/f28x/f2806x/drv8305q1_spi.h"
#include "sw/safety/drv8305q1/src/32b/f28x/f2806x/drv8305q1.h"


DRV8305_Vars_t gDrv8305Vars = DRV8305_DEFAULTS;

void DRV8305_InitRegs(DRV8305_Vars_t *drv8305q1)
{
    drv8305q1->readCmd = false;
    drv8305q1->readStat = false;
    drv8305q1->writeCmd = false;

	drv8305q1->cntrl5_hs_gd.all = 0;
	drv8305q1->cntrl6_ls_gd.all = 0;
	drv8305q1->cntrl7_gd.all = 0;
	drv8305q1->cntrl9_IC_ops.all = 0;
	drv8305q1->cntrlA_shunt_amp.all = 0;
	drv8305q1->cntrlB_Vreg.all = 0;
	drv8305q1->cntrlC_Vds_SNS.all = 0;

	drv8305q1->cntrl5_hs_gd.bit.IDRIVEN_HS = drv8305_idriveN_hs_60mA;
	drv8305q1->cntrl5_hs_gd.bit.IDRIVEP_HS = drv8305_idriveP_hs_50mA;
	drv8305q1->cntrl5_hs_gd.bit.TDRIVEN    = drv8305_tdriveN_250nS;

	drv8305q1->cntrl6_ls_gd.bit.IDRIVEN_LS = drv8305_idriveN_ls_60mA;
	drv8305q1->cntrl6_ls_gd.bit.IDRIVEP_LS = drv8305_idriveP_ls_50mA;
	drv8305q1->cntrl6_ls_gd.bit.TDRIVEP    = drv8305_tdriveP_250nS;

	drv8305q1->cntrl7_gd.bit.COMM_OPTION = drv8305_comm_diode_FW;
	drv8305q1->cntrl7_gd.bit.PWM_MODE    = drv8305_PWM_mode_3;
	drv8305q1->cntrl7_gd.bit.DEAD_TIME   = drv8305_deadTime_60nS;
	drv8305q1->cntrl7_gd.bit.TBLANK      = drv8305_tblank_2us;
	drv8305q1->cntrl7_gd.bit.TVDS        = drv8305_tblank_4us;

	drv8305q1->cntrl9_IC_ops.bit.Flip_OTS        = drv8305_disable_OTS;
	drv8305q1->cntrl9_IC_ops.bit.DIS_VPVDD_UVLO2 = drv8305_enable_PVDD_UVLO2_fault;
	drv8305q1->cntrl9_IC_ops.bit.DIS_GDRV_FAULT  = drv8305_enable_gdrv_fault;
	drv8305q1->cntrl9_IC_ops.bit.EN_SNS_CLAMP    = drv8305_disable_Sns_Clamp;
	drv8305q1->cntrl9_IC_ops.bit.WD_DLY          = drv8305_wd_dly_20mS;
	drv8305q1->cntrl9_IC_ops.bit.DIS_SNS_OCP     = drv8305_enable_SnsOcp;
	drv8305q1->cntrl9_IC_ops.bit.WD_EN           = drv8305_disable_WD;
	drv8305q1->cntrl9_IC_ops.bit.SLEEP           = drv8305_sleep_No;
	drv8305q1->cntrl9_IC_ops.bit.CLR_FLTS        = drv8305_ClrFaults_No;      // fault clearing bit
	drv8305q1->cntrl9_IC_ops.bit.SET_VCPH_UV     = drv8305_set_Vcph_UV_4p9V;

	drv8305q1->cntrlA_shunt_amp.bit.GAIN_CS1   = drv8305_gain_CS_10;
	drv8305q1->cntrlA_shunt_amp.bit.GAIN_CS2   = drv8305_gain_CS_10;
	drv8305q1->cntrlA_shunt_amp.bit.GAIN_CS3   = drv8305_gain_CS_10;
	drv8305q1->cntrlA_shunt_amp.bit.CS_BLANK   = drv8305_cs_blank_0ns;
	drv8305q1->cntrlA_shunt_amp.bit.DC_CAL_CH1 = drv8305_dc_cal_off;
	drv8305q1->cntrlA_shunt_amp.bit.DC_CAL_CH2 = drv8305_dc_cal_off;
	drv8305q1->cntrlA_shunt_amp.bit.DC_CAL_CH3 = drv8305_dc_cal_off;

	drv8305q1->cntrlB_Vreg.bit.VREF_SCALING   = drv8305_vref_scaling_2;
	drv8305q1->cntrlB_Vreg.bit.SLEEP_DLY      = drv8305_sleep_dly_10uS;
	drv8305q1->cntrlB_Vreg.bit.DIS_VREG_PWRGD = 0;                               // temporary //
	drv8305q1->cntrlB_Vreg.bit.VREG_UV_LEVEL  = drv8305_vreg_UV_level_30percent;

//	drv8305q1->cntrlC_Vds_SNS.bit.VDS_LEVEL   = drv8305_vds_level_1175mV;
	drv8305q1->cntrlC_Vds_SNS.bit.VDS_LEVEL   = drv8305_vds_level_1892mV;
	drv8305q1->cntrlC_Vds_SNS.bit.VDS_MODE    = drv8305_vds_mode_latchedShutDown;

	return;
}

//*****************************************************************************
//*****************************************************************************
// Initialise DRV8301
//*****************************************************************************
//*****************************************************************************
void DRV8305_Init(DRV8305_Vars_t *drv8305q1)
{
    DRV8305_InitSPI();
    gSpiMode = SPI_DRV8305;

	// ===============================================================
	// write all control regs, ignore the return value of each write
	// ===============================================================
	DRV8305_SPI_Write(DRV8305_C5_HS_GATE_DRIVER_CNTRL_ADDR, drv8305q1->cntrl5_hs_gd.all);        //write to DRV8305 control reg 5
	DRV8305_SPI_Write(DRV8305_C5_HS_GATE_DRIVER_CNTRL_ADDR, drv8305q1->cntrl6_ls_gd.all);        //write to DRV8305 control reg 6
	DRV8305_SPI_Write(DRV8305_C7_GD_CNTRL_ADDR, drv8305q1->cntrl7_gd.all);                       //write to DRV8305 control reg 7
	DRV8305_SPI_Write(DRV8305_C9_IC_OPS_ADDR, drv8305q1->cntrl9_IC_ops.all);                     //write to DRV8305 control reg 9
	DRV8305_SPI_Write(DRV8305_CA_SHUNT_AMP_CNTRL_ADDR, drv8305q1->cntrlA_shunt_amp.all);         //write to DRV8305 control reg A
	DRV8305_SPI_Write(DRV8305_CB_VREG_CNTRL_ADDR, drv8305q1->cntrlB_Vreg.all);                       //write to DRV8305 control reg B
	DRV8305_SPI_Write(DRV8305_CC_VDS_SNS_CNTRL_ADDR, drv8305q1->cntrlC_Vds_SNS.all);             //write to DRV8305 control reg C

	// ===============================================
	// read all status and control registers
	// ===============================================
	drv8305q1->status1_wwd.all = DRV8305_SPI_Read(DRV8305_S1_WWD_ADDR) & 0x05ff;               // read DRV8305 status reg 1
	drv8305q1->status2_ov_vds.all = DRV8305_SPI_Read(DRV8305_S2_OV_VDS_FAULTS_ADDR) & 0x07e7;  // read DRV8305 status reg 2
	drv8305q1->status3_IC.all = DRV8305_SPI_Read(DRV8305_S3_IC_FAULTS_ADDR) & 0x0777;          // read DRV8305 status reg 3
	drv8305q1->status4_gd_Vgs.all = DRV8305_SPI_Read(DRV8305_S4_GD_VGS_FAULTS_ADDR) & 0x07e0;  // read DRV8305 status reg 4

	drv8305q1->cntrl5_hs_gd.all = DRV8305_SPI_Read(DRV8305_C5_HS_GATE_DRIVER_CNTRL_ADDR) & 0x03ff;  // read DRV8305 control reg 5
	drv8305q1->cntrl6_ls_gd.all = DRV8305_SPI_Read(DRV8305_C6_LS_GATE_DRIVER_CNTRL_ADDR) & 0x03ff;  // read DRV8305 control reg 6
	drv8305q1->cntrl7_gd.all = DRV8305_SPI_Read(DRV8305_C7_GD_CNTRL_ADDR) & 0x03ff;              // read DRV8305 control reg 7
	drv8305q1->cntrl9_IC_ops.all = DRV8305_SPI_Read(DRV8305_C9_IC_OPS_ADDR) & 0x07ff;                // read DRV8305 control reg 9
	drv8305q1->cntrlA_shunt_amp.all = DRV8305_SPI_Read(DRV8305_CA_SHUNT_AMP_CNTRL_ADDR) & 0x07ff;       // read DRV8305 control reg A
	drv8305q1->cntrlB_Vreg.all = DRV8305_SPI_Read(DRV8305_CB_VREG_CNTRL_ADDR) & 0x031f;            // read DRV8305 control reg B
	drv8305q1->cntrlC_Vds_SNS.all = DRV8305_SPI_Read(DRV8305_CC_VDS_SNS_CNTRL_ADDR) & 0x00ff;         // read DRV8305 control reg C

	return;
}

//
void DRV8305_enable(DRV8305_Vars_t *drv8305q1)
{
//    GpioDataRegs.GPBSET.bit.GPIO56 = 1;;        // Enable GATE
    GpioDataRegs.GPACLEAR.bit.GPIO10 = 1;;      // WAKE

    return;
}

//*****************************************************************************
//*****************************************************************************
// DRV based fault diagnostics
//*****************************************************************************
//*****************************************************************************
void DRV8305_readStat(DRV8305_Vars_t *drv8305q1)
{
    if(drv8305q1->readStat == true)
    {
        if(gSpiMode != SPI_DRV8305)
        {
            DRV8305_InitSPI();
            gSpiMode = SPI_DRV8305;
        }

        drv8305q1->status1_wwd.all = DRV8305_SPI_Read(DRV8305_S1_WWD_ADDR) & 0x05ff;               // read DRV8305 status reg 1
        drv8305q1->status2_ov_vds.all = DRV8305_SPI_Read(DRV8305_S2_OV_VDS_FAULTS_ADDR) & 0x07e7;  // read DRV8305 status reg 2
        drv8305q1->status3_IC.all = DRV8305_SPI_Read(DRV8305_S3_IC_FAULTS_ADDR) & 0x0777;          // read DRV8305 status reg 3
        drv8305q1->status4_gd_Vgs.all = DRV8305_SPI_Read(DRV8305_S4_GD_VGS_FAULTS_ADDR) & 0x07e0;  // read DRV8305 status reg 4

        drv8305q1->readStat = false;
    }

	return;
}

void DRV8305_writeCmd(DRV8305_Vars_t *drv8305q1)
{
    if(drv8305q1->writeCmd == true)
    {
        if(gSpiMode != SPI_DRV8305)
        {
            DRV8305_InitSPI();
            gSpiMode = SPI_DRV8305;
        }

        // ===============================================================
        // write all control regs, ignore the return value of each write
        // ===============================================================
        DRV8305_SPI_Write(DRV8305_C5_HS_GATE_DRIVER_CNTRL_ADDR, drv8305q1->cntrl5_hs_gd.all);        //write to DRV8305 control reg 5
        DRV8305_SPI_Write(DRV8305_C6_LS_GATE_DRIVER_CNTRL_ADDR, drv8305q1->cntrl6_ls_gd.all);        //write to DRV8305 control reg 6
        DRV8305_SPI_Write(DRV8305_C7_GD_CNTRL_ADDR, drv8305q1->cntrl7_gd.all);                       //write to DRV8305 control reg 7
        DRV8305_SPI_Write(DRV8305_C9_IC_OPS_ADDR, drv8305q1->cntrl9_IC_ops.all);                      //write to DRV8305 control reg 9
        DRV8305_SPI_Write(DRV8305_CA_SHUNT_AMP_CNTRL_ADDR, drv8305q1->cntrlA_shunt_amp.all);         //write to DRV8305 control reg A
        DRV8305_SPI_Write(DRV8305_CB_VREG_CNTRL_ADDR, drv8305q1->cntrlB_Vreg.all);                   //write to DRV8305 control reg B
        DRV8305_SPI_Write(DRV8305_CC_VDS_SNS_CNTRL_ADDR, drv8305q1->cntrlC_Vds_SNS.all);             //write to DRV8305 control reg C

        drv8305q1->writeCmd = false;
    }

    return;
}

void DRV8305_readCmd(DRV8305_Vars_t *drv8305q1)
{
    if(drv8305q1->readCmd == true)
    {
        if(gSpiMode != SPI_DRV8305)
        {
            DRV8305_InitSPI();
            gSpiMode = SPI_DRV8305;
        }

        drv8305q1->cntrl5_hs_gd.all = DRV8305_SPI_Read(DRV8305_C5_HS_GATE_DRIVER_CNTRL_ADDR) & 0x03ff;  // read DRV8305 control reg 5
        drv8305q1->cntrl6_ls_gd.all = DRV8305_SPI_Read(DRV8305_C6_LS_GATE_DRIVER_CNTRL_ADDR) & 0x03ff;  // read DRV8305 control reg 6
        drv8305q1->cntrl7_gd.all = DRV8305_SPI_Read(DRV8305_C7_GD_CNTRL_ADDR) & 0x03ff;              // read DRV8305 control reg 7
        drv8305q1->cntrl9_IC_ops.all = DRV8305_SPI_Read(DRV8305_C9_IC_OPS_ADDR) & 0x07ff;                // read DRV8305 control reg 9
        drv8305q1->cntrlA_shunt_amp.all = DRV8305_SPI_Read(DRV8305_CA_SHUNT_AMP_CNTRL_ADDR) & 0x07ff;       // read DRV8305 control reg A
        drv8305q1->cntrlB_Vreg.all = DRV8305_SPI_Read(DRV8305_CB_VREG_CNTRL_ADDR) & 0x031f;            // read DRV8305 control reg B
        drv8305q1->cntrlC_Vds_SNS.all = DRV8305_SPI_Read(DRV8305_CC_VDS_SNS_CNTRL_ADDR) & 0x00ff;         // read DRV8305 control reg C

        drv8305q1->readCmd = false;
    }

    return;
}
/****************************************************************************
 * End of Code *
 * ***************************************************************************
 */
