//----------------------------------------------------------------------------------
//	FILE:			drv830x_SPI.c
//
//	Description:	Contains DRV830x SPI driver functions
//
//	Version: 		1.0
//
//  Target:  		TMS320F28377S
//
//----------------------------------------------------------------------------------
//  Copyright Texas Instruments 2004-2015
//----------------------------------------------------------------------------------
//  Revision History:
//----------------------------------------------------------------------------------
//  Date	  | Description / Status
//----------------------------------------------------------------------------------
// 4 Nov 2015 - DRV830x SPI driver functions
//----------------------------------------------------------------------------------

#include "F2806x_Device.h"     // F2806x Headerfile Include File

#include "sw/safety/drv8305q1/src/32b/f28x/f2806x/drv8305q1_spi.h"
#include "sw/safety/drv8305q1/src/32b/f28x/f2806x/drv8305q1.h"

// ****************************************************************************
// SPI Configuration
// ****************************************************************************
void DRV8305_InitSPI(void)
{
    SpiaRegs.SPICCR.bit.SPISWRESET = 0;       // Put SPI in reset state
    SpiaRegs.SPICCR.bit.SPICHAR = 0xF;        // 16-bit character
    SpiaRegs.SPICCR.bit.SPILBK = 0;           // loopback off
    SpiaRegs.SPICCR.bit.CLKPOLARITY = 0;      // Rising edge without delay

    SpiaRegs.SPICTL.bit.SPIINTENA = 0;        // disable SPI interrupt
    SpiaRegs.SPICTL.bit.TALK = 1;             // enable transmission
    SpiaRegs.SPICTL.bit.MASTER_SLAVE = 1;     // master
    SpiaRegs.SPICTL.bit.CLK_PHASE = 0;        // Rising edge without delay
    SpiaRegs.SPICTL.bit.OVERRUNINTENA = 0;    // disable reciever overrun interrupt

    SpiaRegs.SPIBRR = 17;                     // SPICLK = LSPCLK / 4 (max SPICLK), 90M/(17+1)=5MSPS
    SpiaRegs.SPICCR.bit.SPISWRESET=1;         // Enable SPI
}

/*****************************************************************************/
// SPI driver to interface with DRV830x
/*****************************************************************************/
uint16_t DRV8305_SPI_Driver(uint16_t data)
{
    uint16_t dataread;
    uint16_t n;

    GpioDataRegs.GPBCLEAR.bit.GPIO53 = 1;;      // Enable SCS

    for(n=0; n<0x05; n++)
        asm(" NOP");

    // empty RX and TX FIFOs
    SpiaRegs.SPIFFTX.bit.TXFIFO = 0; // reset FIFOs
    SpiaRegs.SPIFFRX.bit.RXFIFORESET = 0;
    asm(" NOP");
    asm(" NOP");
    SpiaRegs.SPIFFTX.bit.TXFIFO = 1;
    SpiaRegs.SPIFFRX.bit.RXFIFORESET = 1; // release from reset

	SpiaRegs.SPITXBUF = data;			        // send out the data

    while (SpiaRegs.SPIFFRX.bit.RXFFST < 1)     // wait for the packet to complete
    {
    }

	dataread = SpiaRegs.SPIRXBUF;				// data read to clear the INT_FLAG bit

    for(n=0; n<0x1F; n++)
        asm(" NOP");

	GpioDataRegs.GPBSET.bit.GPIO53 = 1;         // Disable SCS

	return(dataread);
}

/*****************************************************************************/
// Read from DRV8305 Register at a certain address
/*****************************************************************************/
uint16_t DRV8305_SPI_Read(uint16_t address)
{
	union DRV830x_SPI_WRITE_WORD_REG w;

	w.bit.R_W = 1;							// read - 1
	w.bit.ADDRESS = address;				// load the address
	w.bit.DATA = 0;		                    // data to be written

	return(DRV8305_SPI_Driver(w.all));
}

/*****************************************************************************/
// Write to a DRV8305 Register at a certain address
/*****************************************************************************/
uint16_t DRV8305_SPI_Write(uint16_t address, uint16_t data)
{
	union DRV830x_SPI_WRITE_WORD_REG w;

	w.bit.R_W = 0;							// write - 0
	w.bit.ADDRESS = address;				// load the address
	w.bit.DATA = data;		                // data to be written

	return(DRV8305_SPI_Driver(w.all));
}

/*****************************************************************************/
// EOF
/*****************************************************************************/
