#ifndef _PGA411Q1_SPI_H_
#define _PGA411Q1_SPI_H_
/******************************************************************************
* TIDA-01507 Resolver-to-Uart functionality only (based on TIDA-00796)
* Module: Hardware Abstraction Layer
* Author: Jiri Panacek, j-panacek@ti.com
*
* Copyright 2017 Texas Instruments Incorporated. All rights reserved.
******************************************************************************/

#include "F2806x_Device.h" /* registers definition */

#include "sw/modules/types/src/types.h"
#include "sw/modules/usDelay/src/32b/usDelay.h"
#include "sw/modules/iqmath/src/32b/IQmathLib.h"

/******************************************************************************
 * MACROS
 *****************************************************************************/

/* PGA411 GPIO macros */
                                    // nRST is not implemented in this design
#define    HAL_PGA_RESET_N_LOW      // GpioDataRegs.GPACLEAR.bit.GPIO2 = 1
#define    HAL_PGA_RESET_N_HIGH     // GpioDataRegs.GPASET.bit.GPIO2 = 1
#define    HAL_PGA_FAULTRES_LOW     asm(" EALLOW"); \
                                    GpioCtrlRegs.GPBDIR.bit.GPIO51 = 1; \
                                    GpioDataRegs.GPBCLEAR.bit.GPIO51 = 1; \
                                    asm(" EDIS")
#define    HAL_PGA_FAULTRES_HIZ     asm(" EALLOW"); \
                                    GpioCtrlRegs.GPBDIR.bit.GPIO51 = 0; \
                                    asm(" EDIS")

/* Clock source details */
#define    DSP28_DIVSEL   2   /* Enable /2 for SYSCLKOUT */
#define    DSP28_PLLCR    16  /* set CPU_CLK to 16/2*10 MHz = 80 MHz */
#define    CPU_RATE       12.500L /* for a 80MHz CPU clock speed (SYSCLKOUT) */

/* short delay, reused from F2806x_Examples.h */
#define HAL_DELAY_US(A)  DSP28x_usDelay(((((long double) A * 1000.0L) /      \
                     (long double)CPU_RATE) - 9.0L) / 5.0L)

/******************************************************************************
 * ENUMS
 *****************************************************************************/

/******************************************************************************
 * TYPEDEFS
 *****************************************************************************/

/******************************************************************************
 * VARIABLES, CONSTANTS
 *****************************************************************************/

/******************************************************************************
 * SYSTEM INTERFACE FUNCTIONS PROTOTYPES
 *****************************************************************************/

/* PGA411-Q1 GPIO configuration */
void pga411_InitGPIO(void);

/* SPI init */
void pga411_InitSPI(void);

/* Exchanges 4 Bytes via SPI, blocks until finished, 32b architecture = no pointer */
uint32_t pga411_Xmit4BSPI(uint32_t frame);

/* pseudo assert */
void pga411_assert(void);

#endif /* _PGA411Q1_SPI_H_ */
