/*
 *
 * Copyright (C) 2016 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

/**
 * @file   tps65381.h
 * @author Christian Herget
 * @date   2/3/2017
 * @brief  Header file for TPS65381 driver
 *
 */

#ifndef TPS65381_SPI_H_
#define TPS65381_SPI_H_

#include <stdint.h>

#include "F2806x_Device.h"     // F2806x Headerfile Include File

#include "sw/safety/com_spi/src/32b/f28x/com_spi.h"
#include "sw/modules/types/src/types.h"
#include "sw/modules/usDelay/src/32b/usDelay.h"
#include "sw/modules/iqmath/src/32b/IQmathLib.h"

//=============================================================================
// TPS65381A SPI Input Data bit definitions:
struct  TPS65381A_SPI_WRITE_WORD_BITS {       // bit      description
   uint16_t DATA:8;                           // 7:0
   uint16_t ADDRESS:8;                        // 15:8
};

union TPS65381A_SPI_WRITE_WORD_REG {
   uint16_t                               all;
   struct TPS65381A_SPI_WRITE_WORD_BITS   bit;
};

/*****************************************************************************/
//function prototypes
/*****************************************************************************/
void TPS65381A_InitSPI(void);
uint16_t TPS65381A_SPI_Driver(uint16_t data);
uint16_t TPS65381A_SPI_Read(uint16_t address);
uint16_t TPS65381A_SPI_Write(uint16_t address, uint16_t data);

#endif /* TPS65381_SPI_H_ */
