#ifndef _MAIN_POS_H_
#define _MAIN_POS_H_
/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

//! \file   solutions/instaspin_motion/src/main_position.h
//! \brief Defines the structures, global initialization, and functions used in MAIN 
//!
//! (C) Copyright 2011, Texas Instruments, Inc.

// **************************************************************************
// the includes

// modules
#include "sw/modules/math/src/32b/math.h"

// only needed until IQmath is upgraded to 1.6
#include "sw/modules/iqmath/src/32b/IQLog.h"
#include "sw/modules/memCopy/src/memCopy.h"
#include "sw/modules/est/src/32b/est.h"
#include "sw/modules/svgen/src/32b/svgen_current.h"
#include "sw/modules/fw/src/32b/fw.h"
#include "sw/modules/slip/src/32b/slip.h"


// drivers


// platforms
#include "sw/modules/ctrl/src/32b/ctrlResolver.h"
#include "hal.h"
#include "userResolver.h"


// SpinTAC
#include "spintac_position.h"


// **************************************************************************
// the defines

// The defines for manual control by potentiometer
#define SPEED_EXT_SET_MAX_RPM     1800      // maximum speed = 1800rpm
#define SPEED_EXT_SET_MIN_RPM       30      // minimum speed = 30rpm

#define ADC_SPD_SET_MIN_LOW        100      // the minimum adc input of potentiometer
#define ADC_SPD_SET_MIN_HIGH       300      // the lowest adc input of potentiometer
#define ADC_SPD_SET_MAX_LOW       3900      // the highest adc input of potentiometer

#define ADC_SPEED_SET_SCALE       8388      // the scale coefficient (1800/(3900-300)/1000)*2^24

typedef enum
{
    CTRL_SLESS_SPD       = 0x00,
    CTRL_SLESS_POS       = 0x01,
    CTRL_SNRES_SPD       = 0x02,
    CTRL_SNRES_POS       = 0x03,
    CTRL_SNQEP_SPD       = 0x04,
    CTRL_SNQEP_POS       = 0x05
} CTRL_SENSOR_MODE_e;

// the Falut typedefs
typedef struct _FAULT_BITS_
{                     // bits  description
    uint16_t OverVoltageFault:1;        // 0  DC Bus Over Voltage Fault Flag
    uint16_t UnderVoltageFault:1;       // 1  DC Bus Under Voltage Fault Flag
    uint16_t MotorOverTemperature:1;    // 2  Motor over temperature Fault Flag
    uint16_t ModuleOverTemperature:1;   // 3  Power module over temperature Fault Flag

    uint16_t ModuleOverCurrent:1;       // 4  Hardware Over Current Fault Flag
    uint16_t OverRmsCurrent:1;          // 5  Motor Phase Over Current Fault Flag
    uint16_t MotorStall:1;              // 6 Motor Stall
    uint16_t OverLoadFault:1;           // 7 Over Load Error

    uint16_t MotorLostPhase:1;          // 8  Motor Lost Phase
    uint16_t CurrentUnbalance:1;        // 9  Motor Phase Current Unbalance
    uint16_t OverSpeedFault:1;          // 10 Motor Over Speed
    uint16_t StartupFailed:1;           // 11 Startup failed

    uint16_t Reserve12:1;               // 12 Reserve error
    uint16_t Reserve13:1;               // 13 Reserve error
    uint16_t ControllerError:1;         // 14 FAST Controller error
    uint16_t CommunicationFault:1;      // 15 Communication Fault
}FAULT_BITS;

typedef union _FAULT_REG_
{
    uint16_t     all;
    FAULT_BITS   bit;
}FAULT_REG;

//! \brief Defines the number of main iterations before global variables are updated
//!
#define NUM_MAIN_TICKS_FOR_GLOBAL_VARIABLE_UPDATE  1

//! \brief Defines the speed acceleration scale factor.
//!
#define MAX_ACCEL_KRPMPS_SF  _IQ(USER_MOTOR_NUM_POLE_PAIRS * 1000.0 / USER_TRAJ_FREQ_Hz / USER_IQ_FULL_SCALE_FREQ_Hz / 60.0)

//! \brief Initialization values of global variables
//!
#define MOTOR_Vars_INIT {false, \
                         false, \
                         false, \
                         true, \
                         true, \
                         false, \
                         false, \
                         \
                         true, \
                         true, \
                         false, \
                         \
                         false, \
                         false, \
                         false, \
                         \
                         false, \
                         false, \
                         false, \
                         \
                         CTRL_SLESS_SPD, \
                         0, \
                         0, \
                         0, \
                         0xFFFF, \
                         \
                         CTRL_State_Idle, \
                         EST_State_Idle, \
                         \
                         USER_ErrorCode_NoError, \
                         {0,CTRL_TargetProc_Unknown,0,0}, \
                         \
                         _IQ(0.0), \
                         _IQ(0.0), \
                         \
                         _IQ(0.3), \
                         _IQ(0.3), \
                         _IQ(0.0), \
                         _IQ(0.2), \
                         _IQ(0.2), \
                         _IQ(0.0), \
                         \
                         _IQ(0.0), \
                         _IQ(0.0), \
                         \
                         _IQ(USER_MAX_VS_MAG_PU), \
                         _IQ(0.1 * USER_MOTOR_MAX_CURRENT), \
                         \
                         0.0, \
                         0.0, \
                         0.0, \
                         0.0, \
                         0.0, \
                         0.0, \
                         0.0, \
                         \
                         _IQ(1.0), \
                         _IQ(0.1), \
                         _IQ(0.5), \
                         _IQ(0.05), \
                         _IQ(0.5), \
                         _IQ(0.05), \
                         \
                         _IQ(0.0), \
                         _IQ(0.0), \
                         _IQ(0.0), \
                         _IQ(0.9 * USER_MAX_VS_MAG_PU), \
                         _IQ(0.0), \
                         \
                         _IQ(0.0), \
                         _IQ(0.0), \
                         _IQ(0.0), \
                         \
                         {0,0,0}, \
                         {0,0,0}, \
                         false, \
                         0, \
                         _IQ(0.0), \
                         _IQ(2.0), \
                         _IQ20(5.0), \
                         _IQ(0.0), \
						 ST_VARS_DEFAULTS, \
						 0, 0, \
						 0, 0, 0, 0 \
    }


// **************************************************************************
// the typedefs

typedef struct _MOTOR_Vars_t_
{
  bool Flag_enableSys;
  bool Flag_Run_Identify;
  bool Flag_MotorIdentified;
  bool Flag_enableForceAngle;
  bool Flag_enableUserParams;
  bool Flag_enablePowerWarp;
  bool Flag_enableFieldWeakening;

  bool Flag_enableOffsetcalc;
  bool Flag_enableRsRecalc;
  bool Flag_enableRsOnline;

  bool Flag_enableSpeedCtrl;
  bool Flag_enableSpinTAC;
  bool Flag_enableSensorCtrl;

  bool Flag_enableRdcWandR;
  bool Flag_resolverOffsetDone;
  bool Flag_enableExtSpeedSet;

  CTRL_SENSOR_MODE_e CtrlSensorMode;
  FAULT_REG FaultFlagNow;               // 0x0000
  FAULT_REG FaultFlagUse;               // 0x0000
  FAULT_REG FaultFlagOld;               // 0x0000
  FAULT_REG FaultFlagMask;              // 0x0000

  CTRL_State_e CtrlState;
  EST_State_e EstState;

  USER_ErrorCode_e UserErrorCode;
  CTRL_Version CtrlVersion;

  _iq IdRef_A;
  _iq IqRef_A;

  _iq SpeedExtSet_krpm;
  _iq SpeedRef_krpm;
  _iq SpeedTraj_krpm;
  _iq MaxAccel_krpmps;
  _iq MaxDecel_krpmps;
  _iq Speed_krpm;

  _iq Flux_Wb;
  _iq Torque_Nm;

  _iq OverModulation;
  _iq RsOnLineCurrent_A;

  float_t MagnCurr_A;
  float_t Rr_Ohm;
  float_t Rs_Ohm;
  float_t RsOnLine_Ohm;
  float_t Lsd_H;
  float_t Lsq_H;
  float_t Flux_VpHz;

  _iq Kp_spd;
  _iq Ki_spd;
  _iq Kp_Id;
  _iq Ki_Id;
  _iq Kp_Iq;
  _iq Ki_Iq;

  _iq Vd;
  _iq Vq;
  _iq Vs;
  _iq VsRef;
  _iq VdcBus_kV;

  _iq Id_A;
  _iq Iq_A;
  _iq Is_A;

  MATH_vec3 I_bias;
  MATH_vec3 V_bias;
  
  bool RunPositionProfile;
  int32_t PosStepInt_MRev;
  _iq PosStepFrac_MRev;
  _iq MaxVel_krpm;
  _iq20 MaxJrk_krpmps2;
  _iq PositionError_MRev;

  ST_Vars_t SpinTAC;

  uint16_t timer_0p5ms_cnt;
  uint16_t timer_10ms_cnt;

  uint16_t timer_led1_cnt;
  uint16_t timer_led2_cnt;
  uint16_t timer_led3_cnt;

  uint16_t timer_led1_set;

}MOTOR_Vars_t;


// **************************************************************************
// the globals


// **************************************************************************
// the function prototypes

//! \brief The main interrupt service (ISR) routine
//!
interrupt void mainISR(void);


//! \brief     Updates the global motor variables 
//! 
void updateGlobalVariables_motor(CTRL_Handle handle, ST_Handle stHandle);

//! \brief     Updates Kp and Ki gains in the controller object
//!
void updateKpKiGains(CTRL_Handle handle);


//! \brief     Recalculate Kp and Ki gains to fix the R/L limitation of 2000.0 and Kp limitation of 0.11
//! \brief     as well as recalculates gains based on estimator state to allow low inductance pmsm to id
//!
void recalcKpKiPmsm(CTRL_Handle handle);


//! \brief     Recalculate Kp and Ki gains to fix the R/L limitation of 2000.0 and Kp limitation of 0.11
//!
void recalcKpKi(CTRL_Handle handle);

//! \brief     Calculates the maximum qFmt value for Ls identification, to get a more accurate Ls per unit
//!
void CTRL_calcMax_Ls_qFmt(CTRL_Handle handle, uint_least8_t *p_qFmt);


//! \brief     Reset Ls Q format to a higher value when Ls identification starts
//!
void CTRL_resetLs_qFmt(CTRL_Handle handle, const uint_least8_t qFmt);


//! \brief     Calculates Dir_qFmt for ACIM
//!
void acim_Dir_qFmtCalc(CTRL_Handle handle);


//! \brief     Set electrical frequency limit to zero while identifying an induction motor
//!
void setFeLimitZero(CTRL_Handle handle);


//! \brief     Runs Rs online
//!
void runRsOnLine(CTRL_Handle handle);


//! \brief      Runs Rs Online for lab11a; function prototype changed to expect EST_Handle object
//!             instead of CTRL_Handle object (lab11a features no CTRL object)
//!
void updateRsOnLine(EST_Handle handle);


//@} //defgroup
#endif // end of _MAIN_POS_H_ definition



