/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, LineStream Technologies Incorporated
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
* *  Neither the names of Texas Instruments Incorporated, LineStream
 *    Technologies Incorporated, nor the names of its contributors may be
 *    used to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//! \file   solutions/instaspin_motion/src/proj_lab13e.c
//! \brief  Smooth Velocity Transitions in Position Control
//!
//! (C) Copyright 2012, LineStream Technologies, Inc.
//! (C) Copyright 2011, Texas Instruments, Inc.

//! \defgroup PROJ_LAB13E PROJ_LAB13E
//@{

//! \defgroup PROJ_LAB13E_OVERVIEW Project Overview
//!
//! Smooth Velocity Transitions in Position Control
//!

// **************************************************************************
// the includes

// system includes
#include <math.h>
#include "main_resolver.h"

#ifdef FLASH
#pragma CODE_SECTION(mainISR,"ramfuncs");
#endif

// Include header files used in the main function


// **************************************************************************
// the defines

#define LED_BLINK_FREQ_Hz   5


// **************************************************************************
// the globals
bool Flag_Latch_softwareUpdate = true;

CTRL_Handle ctrlHandle;

HAL_Handle halHandle;

USER_Params gUserParams;

HAL_PwmData_t gPwmData = {_IQ(0.0), _IQ(0.0), _IQ(0.0)};

HAL_AdcData_t gAdcData;
HAL_AdcSetData_t gAdcSetData;

_iq gMaxCurrentSlope = _IQ(0.0);

#ifdef FAST_ROM_V1p6
CTRL_Obj *controller_obj;
#else
CTRL_Obj ctrl;				//v1p7 format
#endif

ENC_Handle encHandle;
ENC_Obj enc;

SLIP_Handle slipHandle;
SLIP_Obj slip;

ST_Obj st_obj;
ST_Handle stHandle;

volatile MOTOR_Vars_t gMotorVars = MOTOR_Vars_INIT;

#ifdef FLASH
// Used for running BackGround in flash, and ISR in RAM
extern uint16_t *RamfuncsLoadStart, *RamfuncsLoadEnd, *RamfuncsRunStart;
#endif

_iq gLs_pu = _IQ30(0.0);
uint_least8_t gLs_qFmt = 0;
uint_least8_t gMax_Ls_qFmt = 0;

_iq gFlux_pu_to_Wb_sf;
_iq gFlux_pu_to_VpHz_sf;
_iq gTorque_Ls_Id_Iq_pu_to_Nm_sf;
_iq gTorque_Flux_Iq_pu_to_Nm_sf;

_iq gAngleEst = _IQ(0.0);
_iq gAngleSen = _IQ(0.0);
_iq gSpeedEst = _IQ(0.0);
_iq gSpeedSen = _IQ(0.0);
_iq gAngleError = _IQ(0.0);
_iq gSpeedError = _IQ(0.0);

// **************************************************************************
// the functions

void main(void)
{
  uint_least8_t estNumber = 0;

#ifdef FAST_ROM_V1p6
  uint_least8_t ctrlNumber = 0;
#endif

  // Only used if running from FLASH
  // Note that the variable FLASH is defined by the project
  #ifdef FLASH
  // Copy time critical code and Flash setup code to RAM
  // The RamfuncsLoadStart, RamfuncsLoadEnd, and RamfuncsRunStart
  // symbols are created by the linker. Refer to the linker files.
  memCopy((uint16_t *)&RamfuncsLoadStart,(uint16_t *)&RamfuncsLoadEnd,(uint16_t *)&RamfuncsRunStart);
  #endif

  // initialize the hardware abstraction layer
  halHandle = HAL_init(&hal,sizeof(hal));


  // check for errors in user parameters
  USER_checkForErrors(&gUserParams);


  // store user parameter error in global variable
  gMotorVars.UserErrorCode = USER_getErrorCode(&gUserParams);


  // do not allow code execution if there is a user parameter error
  if(gMotorVars.UserErrorCode != USER_ErrorCode_NoError)
    {
      for(;;)
        {
          gMotorVars.Flag_enableSys = false;
        }
    }


  // initialize the user parameters
  USER_setParams(&gUserParams);


  // set the hardware abstraction layer parameters
  HAL_setParams(halHandle,&gUserParams);


  // initialize the controller
#ifdef FAST_ROM_V1p6
  ctrlHandle = CTRL_initCtrl(ctrlNumber, estNumber);  		//v1p6 format (06xF and 06xM devices)
  controller_obj = (CTRL_Obj *)ctrlHandle;
#else
  ctrlHandle = CTRL_initCtrl(estNumber,&ctrl,sizeof(ctrl));	//v1p7 format default
#endif

  {
    CTRL_Version version;

    // get the version number
    CTRL_getVersion(ctrlHandle,&version);

    gMotorVars.CtrlVersion = version;
  }

  //TODO: CTRL_setParams
  // enable/disable the use of motor parameters being loaded from user.h
//  gMotorVars.Flag_enableUserParams = true;
  gMotorVars.Flag_enableUserParams = false;       // To identify the motor parameters

  // enable/disable Rs online calibration during motor running
  gMotorVars.Flag_enableRsOnline = false;

  // enable/disable Rs recalibration during motor startup
  gMotorVars.Flag_enableRsRecalc = false;

  // enable/disable automatic calculation of bias values
  gMotorVars.Flag_enableOffsetcalc = true;

  // enable/disable force angle for motor startup
//  gMotorVars.Flag_enableForceAngle = true;
  gMotorVars.Flag_enableForceAngle = false;

  gMotorVars.Flag_enableSpinTAC = false;
  gMotorVars.Flag_enableSpeedCtrl = true;

  // nable/disable resolver offset calibration
  gPga411q1Vars.angleOffset = _IQ(0.1625731587);
  gMotorVars.Flag_resolverOffsetDone = false;           // Enable offset calibration during power up
//  gMotorVars.Flag_resolverOffsetDone = true;          // Disable offset calibration during power up

  // Enable/disable the resolver sensor control
  gMotorVars.Flag_enableSensorCtrl = true;              // With using resolver sensor for motor drive
//  gMotorVars.Flag_enableSensorCtrl = false;           // Without using resolver sensor for motor drive

  // Enable/disable manual speed set
  gMotorVars.Flag_enableExtSpeedSet = false;          // Disable manual speed set by external adc input
//  gMotorVars.Flag_enableExtSpeedSet = true;             // Enable manual speed set by external adc input

  if(gMotorVars.Flag_enableUserParams == false)
  {
      gMotorVars.Flag_resolverOffsetDone = true;
      gMotorVars.Flag_enableSensorCtrl = false;
      gMotorVars.Flag_enableExtSpeedSet = false;
  }

  gMotorVars.FaultFlagUse.all = 0;
  gMotorVars.FaultFlagNow.all = 0;
  gMotorVars.FaultFlagOld.all = 0;

  // set the default controller parameters
  CTRL_setParams(ctrlHandle,&gUserParams);

  // setup faults
  HAL_setupFaults(halHandle);


  // initialize the interrupt vector table
  HAL_initIntVectorTable(halHandle);


  // enable the ADC interrupts
  HAL_enableAdcInts(halHandle);


  // enable global interrupts
  HAL_enableGlobalInts(halHandle);

  // enable debug interrupts
  HAL_enableDebugInt(halHandle);

  // disable the PWM
  HAL_disablePwm(halHandle);


  // TODO:
  TPS65381A_InitRegister(&gTps65381aVars);
  TPS65381A_Init(&gTps65381aVars);

  DRV8305_enable(&gDrv8305Vars);
  DRV8305_InitRegs(&gDrv8305Vars);
  DRV8305_Init(&gDrv8305Vars);

  pga411_Init();                            /* inits PGA411 driver */
  pga411_DefaultCfg(&gPga411q1Vars);        /* default config defined in "pga411_regs" */
  usDelay(10000);                           /* 10 ms deglitch period when the exciter enables */
  pga411_FaultReset();                      /* clear faults if any */

  // initialize the ENC module
  encHandle = ENC_init(&enc, sizeof(enc));


  // setup the ENC module
  ENC_setup(encHandle, 1, USER_MOTOR_NUM_POLE_PAIRS, USER_MOTOR_ENCODER_LINES, 0, USER_IQ_FULL_SCALE_FREQ_Hz, USER_ISR_FREQ_Hz, 8000.0);


  // initialize the SLIP module
  slipHandle = SLIP_init(&slip, sizeof(slip));


  // setup the SLIP module
  SLIP_setup(slipHandle, _IQ(gUserParams.ctrlPeriod_sec));


  // initialize the SpinTAC Components
  stHandle = ST_init(&st_obj, sizeof(st_obj));
  
  
  // setup the SpinTAC Components
  ST_setupPosConv(stHandle);
  ST_setupPosCtl(stHandle);
  ST_setupPosMove(stHandle);
  gMotorVars.MaxVel_krpm = 0;

#ifdef _DLOG_EN_
  // Initialize Datalog
  datalogHandle = DATALOG_init(&datalog,sizeof(datalog));

  // Connect inputs of the datalog module
  datalog.iptr[0] = &gAngleEst;       // datalogBuff[0]
  datalog.iptr[1] = &gAngleSen;       // datalogBuff[1]

//  datalog.iptr[0] = &gAngleSen;       // datalogBuff[0]
//  datalog.iptr[1] = &gSpeedSen;       // datalogBuff[1]

  datalog.trig_value = _IQ(0.5);
#endif

  // enable DC bus compensation
  CTRL_setFlag_enableDcBusComp(ctrlHandle, true);

  // compute scaling factors for flux and torque calculations
  gFlux_pu_to_Wb_sf = USER_computeFlux_pu_to_Wb_sf();
  gFlux_pu_to_VpHz_sf = USER_computeFlux_pu_to_VpHz_sf();
  gTorque_Ls_Id_Iq_pu_to_Nm_sf = USER_computeTorque_Ls_Id_Iq_pu_to_Nm_sf();
  gTorque_Flux_Iq_pu_to_Nm_sf = USER_computeTorque_Flux_Iq_pu_to_Nm_sf();

  HAL_turnLedOff(halHandle,(GPIO_Number_e)HAL_Gpio_LED3);

  for(;;)
  {
    // Waiting for enable system flag to be set
    while(!(gMotorVars.Flag_enableSys))
    {
        gMotorVars.Flag_enableSys = true;
    }

    // loop while the enable system flag is true
    while(gMotorVars.Flag_enableSys)
      {
        CTRL_Obj *obj = (CTRL_Obj *)ctrlHandle;
        ST_Obj *stObj = (ST_Obj *)stHandle;

        // Enable the Library internal PI.  Iq is referenced by the speed PI now
        CTRL_setFlag_enableSpeedCtrl(ctrlHandle, true);

        // Enable/disable the resolver sensor control
        CTRL_setFlag_enableSensorCtrl(ctrlHandle, gMotorVars.Flag_enableSensorCtrl);

        if(HAL_getPwmEnableStatus(halHandle) == true)
        {
            if(HAL_readGpio(halHandle, GPIO_Number_41) == false)
            {
                gMotorVars.FaultFlagNow.bit.ModuleOverCurrent = 1;
            }
        }

        gMotorVars.FaultFlagUse.all = gMotorVars.FaultFlagNow.all & gMotorVars.FaultFlagMask.all;
        gMotorVars.FaultFlagOld.all |= gMotorVars.FaultFlagNow.all;

        if(gMotorVars.FaultFlagUse.all != 0)
        {
            gMotorVars.Flag_Run_Identify = false;

            // disable the PWM
            HAL_disablePwm(halHandle);
        }

        // 1ms
        if(HAL_getCpuTimerStatus(halHandle,0))                  // 1ms time base
        {
            HAL_clearCpuTimerFlag(halHandle,0);

            gMotorVars.timer_0p5ms_cnt++;

        }//End if(HAL_getCpuTimerStatus(halHandle,0))         // 1ms time base

        // 10ms
        if(HAL_getCpuTimerStatus(halHandle,1))         // 10ms time base
        {
            HAL_clearCpuTimerFlag(halHandle,1);

            gMotorVars.timer_10ms_cnt++;

            gMotorVars.timer_led1_cnt++;

            if(gMotorVars.SpeedRef_krpm < _IQ(3.0))
                gMotorVars.timer_led1_set = 150 - _IQmpyI32int(gMotorVars.SpeedRef_krpm, 50);
            else
                gMotorVars.timer_led1_set = 10;

            if(gMotorVars.timer_led1_cnt > gMotorVars.timer_led1_set)
            {
                if(gMotorVars.Flag_Run_Identify == true)
                    HAL_toggleLed(halHandle,(GPIO_Number_e)HAL_Gpio_LED3);
                else if(gMotorVars.FaultFlagUse.all == 0)
                    HAL_turnLedOff(halHandle,(GPIO_Number_e)HAL_Gpio_LED3);
                else
                    HAL_turnLedOn(halHandle,(GPIO_Number_e)HAL_Gpio_LED3);

                gMotorVars.timer_led1_cnt = 0;
            }

         }//End if(HAL_getCpuTimerStatus(halHandle,1))         // 10ms time base

        // enable/disable the use of motor parameters being loaded from user.h
        CTRL_setFlag_enableUserMotorParams(ctrlHandle,gMotorVars.Flag_enableUserParams);

        // convert the ADC data
        HAL_readAdcSetData(halHandle,&gAdcSetData);

        if(gMotorVars.Flag_enableExtSpeedSet == true)
        {
            if(gAdcSetData.speedSet > ADC_SPD_SET_MIN_LOW)
            {
                if(gAdcSetData.speedSet < ADC_SPD_SET_MIN_HIGH)
                {
                    gMotorVars.SpeedExtSet_krpm = _IQ(SPEED_EXT_SET_MIN_RPM/1000.0);
                }
                else if(gAdcSetData.speedSet > ADC_SPD_SET_MAX_LOW)
                {
                    gMotorVars.SpeedExtSet_krpm = _IQ(SPEED_EXT_SET_MAX_RPM/1000.0);
                }
                else
                {
                    gMotorVars.SpeedExtSet_krpm = ((_iq)(gAdcSetData.speedSet-ADC_SPD_SET_MIN_HIGH) * ADC_SPEED_SET_SCALE)
                                                     + _IQ(SPEED_EXT_SET_MIN_RPM/1000.0);
                }

                if(gMotorVars.FaultFlagUse.all == 0)
                {
                    gMotorVars.Flag_Run_Identify = true;
                    gMotorVars.SpeedRef_krpm = gMotorVars.SpeedExtSet_krpm;
                }
                else
                {
                    gMotorVars.Flag_Run_Identify = false;
                    gMotorVars.SpeedRef_krpm = _IQ(0.0);
                }
            }
            else
            {
                gMotorVars.Flag_Run_Identify = false;
                gMotorVars.SpeedRef_krpm = _IQ(0.0);
            }
        }

        // enable/disable Rs recalibration during motor startup
        if(gMotorVars.Flag_resolverOffsetDone == false)
        {
            EST_setFlag_enableRsRecalc(obj->estHandle,true);
        }
        else
        {
            EST_setFlag_enableRsRecalc(obj->estHandle,gMotorVars.Flag_enableRsRecalc);
        }

        // enable/disable automatic calculation of bias values
        CTRL_setFlag_enableOffset(ctrlHandle,gMotorVars.Flag_enableOffsetcalc);


        if(CTRL_isError(ctrlHandle))
          {
            // set the enable controller flag to false
            CTRL_setFlag_enableCtrl(ctrlHandle,false);

            // set the enable system flag to false
            gMotorVars.Flag_enableSys = false;

            // disable the PWM
            HAL_disablePwm(halHandle);
          }
        else
          {
            // update the controller state
            bool flag_ctrlStateChanged = CTRL_updateState(ctrlHandle);

            // enable or disable the control
            CTRL_setFlag_enableCtrl(ctrlHandle, gMotorVars.Flag_Run_Identify);

            if(gMotorVars.Flag_Run_Identify == true)
                gMotorVars.Flag_enableRdcWandR = true;

            if(flag_ctrlStateChanged)
              {
                CTRL_State_e ctrlState = CTRL_getState(ctrlHandle);

                if(ctrlState == CTRL_State_OffLine)
                  {
                    // enable the PWM
                    HAL_enablePwm(halHandle);
                  }
                else if(ctrlState == CTRL_State_OnLine)
                  {
                    if(gMotorVars.Flag_enableOffsetcalc == true)
                    {
                      // update the ADC bias values
                      HAL_updateAdcBias(halHandle);
                    }
                    else
                    {
                      // set the current bias
                      HAL_setBias(halHandle,HAL_SensorType_Current,0,_IQ(I_A_offset));
                      HAL_setBias(halHandle,HAL_SensorType_Current,1,_IQ(I_B_offset));
                      HAL_setBias(halHandle,HAL_SensorType_Current,2,_IQ(I_C_offset));

                      // set the voltage bias
                      HAL_setBias(halHandle,HAL_SensorType_Voltage,0,_IQ(V_A_offset));
                      HAL_setBias(halHandle,HAL_SensorType_Voltage,1,_IQ(V_B_offset));
                      HAL_setBias(halHandle,HAL_SensorType_Voltage,2,_IQ(V_C_offset));
                    }

                    // Return the bias value for currents
                    gMotorVars.I_bias.value[0] = HAL_getBias(halHandle,HAL_SensorType_Current,0);
                    gMotorVars.I_bias.value[1] = HAL_getBias(halHandle,HAL_SensorType_Current,1);
                    gMotorVars.I_bias.value[2] = HAL_getBias(halHandle,HAL_SensorType_Current,2);

                    // Return the bias value for voltages
                    gMotorVars.V_bias.value[0] = HAL_getBias(halHandle,HAL_SensorType_Voltage,0);
                    gMotorVars.V_bias.value[1] = HAL_getBias(halHandle,HAL_SensorType_Voltage,1);
                    gMotorVars.V_bias.value[2] = HAL_getBias(halHandle,HAL_SensorType_Voltage,2);

                    // enable the PWM
                    HAL_enablePwm(halHandle);
                  }
                else if(ctrlState == CTRL_State_Idle)
                  {
                    // disable the PWM
                    HAL_disablePwm(halHandle);
                    gMotorVars.Flag_Run_Identify = false;
                  }

                if((CTRL_getFlag_enableUserMotorParams(ctrlHandle) == true) &&
                  (ctrlState > CTRL_State_Idle) &&
                  (gMotorVars.CtrlVersion.minor == 6))
                  {
                    // call this function to fix 1p6
                    USER_softwareUpdate1p6(ctrlHandle);
                  }
              }
          }


        if(EST_isMotorIdentified(obj->estHandle))
          {
            // set the current ramp
            EST_setMaxCurrentSlope_pu(obj->estHandle,gMaxCurrentSlope);
            gMotorVars.Flag_MotorIdentified = true;

            // set the speed acceleration
            CTRL_setMaxAccel_pu(ctrlHandle,_IQmpy(MAX_ACCEL_KRPMPS_SF,gMotorVars.MaxAccel_krpmps));

            if(gMotorVars.Flag_enableSpinTAC == true)
            {
                // set the speed reference
                CTRL_setSpd_ref_krpm(ctrlHandle,STPOSMOVE_getVelocityReference(stObj->posMoveHandle));

                // enable the SpinTAC Position Controller
                STPOSCTL_setEnable(stObj->posCtlHandle, true);

                if(EST_getState(obj->estHandle) != EST_State_OnLine)
                {
                    // if the system is not running, disable SpinTAC Position Controller
                    STPOSCTL_setEnable(stObj->posCtlHandle, false);
                    // If motor is not running, feed the position feedback into SpinTAC Position Move
                    STPOSMOVE_setPositionStart_mrev(stObj->posMoveHandle, STPOSCONV_getPosition_mrev(stObj->posConvHandle));
                }
            }
            else if(gMotorVars.Flag_enableSpeedCtrl == true)
            {
                // set the speed reference
                CTRL_setSpd_ref_krpm(ctrlHandle,gMotorVars.SpeedRef_krpm);
            }

            if(Flag_Latch_softwareUpdate)
            {
              Flag_Latch_softwareUpdate = false;

              USER_calcPIgains(ctrlHandle);
			  
              // initialize the watch window kp and ki current values with pre-calculated values
              gMotorVars.Kp_spd = CTRL_getKp(ctrlHandle,CTRL_Type_PID_spd);
              gMotorVars.Ki_spd = CTRL_getKi(ctrlHandle,CTRL_Type_PID_spd);

              gMotorVars.Kp_Id = CTRL_getKp(ctrlHandle,CTRL_Type_PID_Id);
              gMotorVars.Ki_Id = CTRL_getKi(ctrlHandle,CTRL_Type_PID_Id);
              gMotorVars.Kp_Iq = CTRL_getKp(ctrlHandle,CTRL_Type_PID_Iq);
              gMotorVars.Ki_Iq = CTRL_getKi(ctrlHandle,CTRL_Type_PID_Iq);

			  // initialize the watch window Bw value with the default value
              gMotorVars.SpinTAC.PosCtlBw_radps = STPOSCTL_getBandwidth_radps(stObj->posCtlHandle);

              // initialize the watch window with maximum and minimum Iq reference
              gMotorVars.SpinTAC.PosCtlOutputMax_A = _IQmpy(STPOSCTL_getOutputMaximum(stObj->posCtlHandle), _IQ(USER_IQ_FULL_SCALE_CURRENT_A));
              gMotorVars.SpinTAC.PosCtlOutputMin_A = _IQmpy(STPOSCTL_getOutputMinimum(stObj->posCtlHandle), _IQ(USER_IQ_FULL_SCALE_CURRENT_A));
            }

          }
        else
          {
            Flag_Latch_softwareUpdate = true;

            // the estimator sets the maximum current slope during identification
            gMaxCurrentSlope = EST_getMaxCurrentSlope_pu(obj->estHandle);
          }

        if(CTRL_getMotorType(ctrlHandle) == MOTOR_Type_Induction)
          {
            // recalculate Kp and Ki gains to fix the R/L limitation of 2000.0, and Kp limit to 0.11
            recalcKpKi(ctrlHandle);

            // set electrical frequency limit to zero while identifying an induction motor
            setFeLimitZero(ctrlHandle);

            // calculate Dir_qFmt for acim motors
            acim_Dir_qFmtCalc(ctrlHandle);
          }
        else
          {
            // recalculate Kp and Ki gains to fix the R/L limitation of 2000.0, and Kp limit to 0.11
            // as well as recalculates gains based on estimator state to allow low inductance pmsm to id
            recalcKpKiPmsm(ctrlHandle);

            // calculate an Ls qFmt that allows ten times smaller inductance compared to Lhf
            CTRL_calcMax_Ls_qFmt(ctrlHandle, &gMax_Ls_qFmt);

            gLs_pu = EST_getLs_d_pu(obj->estHandle);
            gLs_qFmt = EST_getLs_qFmt(obj->estHandle);
          }

        // update the global variables
        updateGlobalVariables_motor(ctrlHandle, stHandle);

        // update Kp and Ki gains
        updateKpKiGains(ctrlHandle);

        // run Rs online
        runRsOnLine(ctrlHandle);

        // set the SpinTAC (ST) bandwidth scale
        STPOSCTL_setBandwidth_radps(stObj->posCtlHandle, gMotorVars.SpinTAC.PosCtlBw_radps);

        // set the maximum and minimum values for Iq reference
        STPOSCTL_setOutputMaximums(stObj->posCtlHandle, _IQmpy(gMotorVars.SpinTAC.PosCtlOutputMax_A, _IQ(1.0/USER_IQ_FULL_SCALE_CURRENT_A)), _IQmpy(gMotorVars.SpinTAC.PosCtlOutputMin_A, _IQ(1.0/USER_IQ_FULL_SCALE_CURRENT_A)));

        // enable/disable the forced angle
        EST_setFlag_enableForceAngle(obj->estHandle,gMotorVars.Flag_enableForceAngle);

        // enable or disable power warp
        CTRL_setFlag_enablePowerWarp(ctrlHandle,gMotorVars.Flag_enablePowerWarp);

        //TODO:
        TPS65381A_ReadSafetyStatus(&gTps65381aVars);
        TPS65381A_ReadWdStatus(&gTps65381aVars);

        DRV8305_writeCmd(&gDrv8305Vars);
        DRV8305_readStat(&gDrv8305Vars);
        DRV8305_readCmd(&gDrv8305Vars);

        pga411_GetAngle(&gPga411q1Vars);
        pga411_GetVelocity(&gPga411q1Vars);

      } // end of while(gFlag_enableSys) loop


    // disable the PWM
    HAL_disablePwm(halHandle);

    // set the default controller parameters (Reset the control to re-identify the motor)
    CTRL_setParams(ctrlHandle,&gUserParams);
    gMotorVars.Flag_Run_Identify = false;
	
    // setup the SpinTAC Components
    ST_setupPosConv(stHandle);
    ST_setupPosCtl(stHandle);
    ST_setupPosMove(stHandle);
    gMotorVars.MaxVel_krpm = 0;

  } // end of for(;;) loop

} // end of main() function

// TODO: mainISR
interrupt void mainISR(void)
{

  static uint16_t stCnt = 0;
  CTRL_Obj *obj = (CTRL_Obj *)ctrlHandle;

  // turn on LED3
  gMotorVars.timer_led3_cnt++;
  if(gMotorVars.timer_led3_cnt > 5000)
  {
      HAL_toggleLed(halHandle,(GPIO_Number_e)HAL_Gpio_LED1);
      gMotorVars.timer_led3_cnt = 0;
  }

  // acknowledge the ADC interrupt
  HAL_acqAdcInt(halHandle,ADC_IntNumber_1);

  if(gTps65381aVars.SAFETY_STAT_5.bit.STAT_FSM == FSM_ACTIVE)
      gTps65381aVars.wdTrigTimeCnt++;

  if(gTps65381aVars.wdTrigTimeCnt >= gTps65381aVars.wdTrigTimeSet)
  {
      gTps65381aVars.wdTrigTimeCnt = 0;
      gTps65381aVars.wdTrigState = WD_TRIG_CMD;
  }

  if(gTps65381aVars.wdTrigState == WD_TRIG_CMD)
  {
      HAL_setGpioHigh(halHandle,GPIO_Number_54);
      gTps65381aVars.wdTrigState = WD_TRIG_SET;
      HAL_toggleLed(halHandle,(GPIO_Number_e)HAL_Gpio_LED2);
  }
  else
  {
      HAL_setGpioLow(halHandle,GPIO_Number_54);
      gTps65381aVars.wdTrigState = WD_TRIG_STANDBY;
  }

  if(gMotorVars.Flag_enableRdcWandR == true)
  {
      gPga411q1Vars.readAngle = true;
      gPga411q1Vars.readVelocity = true;
  }

  // compute the electrical angle
  ENC_calcElecAngle(encHandle, HAL_getQepPosnCounts(halHandle));

  // For the compare between sensorless and resolver sensored
  gAngleEst = EST_getAngle_pu(obj->estHandle);
  gAngleSen = gPga411q1Vars.angle_pu;
  gAngleError = gAngleEst - gAngleSen;

  gSpeedEst = EST_getFm_pu(obj->estHandle);
  gSpeedSen = gPga411q1Vars.velocity_pu;
  gSpeedError = gSpeedEst - gSpeedSen;


  // convert the ADC data
  HAL_readAdcData(halHandle,&gAdcData);


  // Run the SpinTAC Components
  if((stCnt++ >= ISR_TICKS_PER_SPINTAC_TICK) &&(gMotorVars.Flag_enableSpinTAC == true))
  {
	  ST_runPosConv(stHandle, encHandle, ctrlHandle);
	  ST_runPosMove(stHandle);
	  ST_runPosCtl(stHandle, ctrlHandle);
	  stCnt = 1;
  }

  if(USER_MOTOR_TYPE == MOTOR_Type_Induction)
  {
    // update the electrical angle for the SLIP module
    SLIP_setElectricalAngle(slipHandle, ENC_getElecAngle(encHandle));

    // compute the amount of slip
    SLIP_run(slipHandle);

    // run the controller
    CTRL_setSpeedSensor(ctrlHandle,gSpeedSen);
    CTRL_setAngleSensor(ctrlHandle,gAngleSen);
    CTRL_run(ctrlHandle,halHandle,&gAdcData,&gPwmData);
  }
  else
  {
    // run the controller
    CTRL_setSpeedSensor(ctrlHandle,gSpeedSen);
    CTRL_setAngleSensor(ctrlHandle,gAngleSen);
    CTRL_run(ctrlHandle,halHandle,&gAdcData,&gPwmData);
  }

  // write the PWM compare values
  HAL_writePwmData(halHandle,&gPwmData);

  // setup the controller
  CTRL_setup(ctrlHandle);

  // if we are forcing alignment, using the Rs Recalculation, align the eQEP angle with the rotor angle
  if((EST_getState(obj->estHandle) == EST_State_Rs) && (USER_MOTOR_TYPE == MOTOR_Type_Pm))
  {
	  ENC_setZeroOffset(encHandle, (uint32_t)(HAL_getQepPosnMaximum(halHandle) - HAL_getQepPosnCounts(halHandle)));
	  gPga411q1Vars.angleOffset = (gPga411q1Vars.angleOffset*3 + gPga411q1Vars.angle)>>2;
  }

  // low inductance
  if(CTRL_getMotorType(ctrlHandle) == MOTOR_Type_Pm)
  {
      // reset Ls Q format to a higher value when Ls identification starts
      CTRL_resetLs_qFmt(ctrlHandle, gMax_Ls_qFmt);
  }

#ifdef _DLOG_EN_
  DATALOG_update(datalogHandle);
#endif

  return;
} // end of mainISR() function

// TODO: updateGlobalVariables_motor
void updateGlobalVariables_motor(CTRL_Handle handle, ST_Handle sthandle)
{
  uint32_t ProTime_tick, ProTime_mtick;
  CTRL_Obj *obj = (CTRL_Obj *)handle;
  ST_Obj *stObj = (ST_Obj *)sthandle;

  if(gMotorVars.Flag_enableSpinTAC == true)
  {
      // get the speed estimate
      gMotorVars.Speed_krpm = _IQmpy(STPOSCONV_getVelocityFiltered(stObj->posConvHandle), _IQ(ST_SPEED_KRPM_PER_PU));

      // get the position error
      gMotorVars.PositionError_MRev = STPOSCTL_getPositionError_mrev(stObj->posCtlHandle);

      // gets the Position Controller status
      gMotorVars.SpinTAC.PosCtlStatus = STPOSCTL_getStatus(stObj->posCtlHandle);

      // get the inertia setting
      gMotorVars.SpinTAC.InertiaEstimate_Aperkrpm = _IQmpy(STPOSCTL_getInertia(stObj->posCtlHandle), _IQ(ST_SPEED_PU_PER_KRPM * USER_IQ_FULL_SCALE_CURRENT_A));

      // get the friction setting
      gMotorVars.SpinTAC.FrictionEstimate_Aperkrpm = _IQmpy(STPOSCTL_getFriction(stObj->posCtlHandle), _IQ(ST_SPEED_PU_PER_KRPM * USER_IQ_FULL_SCALE_CURRENT_A));

      // get the Position Controller error
      gMotorVars.SpinTAC.PosCtlErrorID = STPOSCTL_getErrorID(stObj->posCtlHandle);

      // get the Position Move status
      gMotorVars.SpinTAC.PosMoveStatus = STPOSMOVE_getStatus(stObj->posMoveHandle);

      // get the Position Move profile time
      STPOSMOVE_getProfileTime_tick(stObj->posMoveHandle, &ProTime_tick, &ProTime_mtick);
      gMotorVars.SpinTAC.PosMoveTime_ticks = ProTime_tick;
      gMotorVars.SpinTAC.PosMoveTime_mticks = ProTime_mtick;

      // get the Position Move error
      gMotorVars.SpinTAC.PosMoveErrorID = STPOSMOVE_getErrorID(stObj->posMoveHandle);

      // get the Position Converter error
      gMotorVars.SpinTAC.PosConvErrorID = STPOSCONV_getErrorID(stObj->posConvHandle);

      // get the Iq reference from the position controller
      gMotorVars.IqRef_A = _IQmpy(STPOSCTL_getTorqueReference(stObj->posCtlHandle), _IQ(USER_IQ_FULL_SCALE_CURRENT_A));
  }
  else
  {
      // get the speed estimate
      gMotorVars.Speed_krpm = EST_getSpeed_krpm(obj->estHandle);

      // get the real time speed reference coming out of the speed trajectory generator
      gMotorVars.SpeedTraj_krpm = _IQmpy(CTRL_getSpd_int_ref_pu(handle),EST_get_pu_to_krpm_sf(obj->estHandle));

      // read Id and Iq vectors in amps
      gMotorVars.IdRef_A = _IQmpy(PID_getRefValue(obj->pidHandle_Id), _IQ(USER_IQ_FULL_SCALE_CURRENT_A));
      gMotorVars.IqRef_A = _IQmpy(PID_getRefValue(obj->pidHandle_Iq), _IQ(USER_IQ_FULL_SCALE_CURRENT_A));
  }

  // get the torque estimate
  gMotorVars.Torque_Nm = USER_computeTorque_Nm(handle, gTorque_Flux_Iq_pu_to_Nm_sf, gTorque_Ls_Id_Iq_pu_to_Nm_sf);

  // get the magnetizing current
  gMotorVars.MagnCurr_A = EST_getIdRated(obj->estHandle);

  // get the rotor resistance
  gMotorVars.Rr_Ohm = EST_getRr_Ohm(obj->estHandle);

  // get the stator resistance
  gMotorVars.Rs_Ohm = EST_getRs_Ohm(obj->estHandle);

  // get the stator inductance in the direct coordinate direction
  gMotorVars.Lsd_H = EST_getLs_d_H(obj->estHandle);

  // get the stator inductance in the quadrature coordinate direction
  gMotorVars.Lsq_H = EST_getLs_q_H(obj->estHandle);

  // get the flux in V/Hz in floating point
  gMotorVars.Flux_VpHz = EST_getFlux_VpHz(obj->estHandle);

  // get the flux in Wb in fixed point
  gMotorVars.Flux_Wb = USER_computeFlux(handle, gFlux_pu_to_Wb_sf);

  // get the controller state
  gMotorVars.CtrlState = CTRL_getState(handle);

  // get the estimator state
  gMotorVars.EstState = EST_getState(obj->estHandle);

  if(gMotorVars.EstState == EST_State_OnLine)
      gMotorVars.Flag_resolverOffsetDone = true;

  // Get the DC buss voltage
  gMotorVars.VdcBus_kV = _IQmpy(gAdcData.dcBus,_IQ(USER_IQ_FULL_SCALE_VOLTAGE_V/1000.0));

  // read Vd and Vq vectors per units
  gMotorVars.Vd = CTRL_getVd_out_pu(handle);
  gMotorVars.Vq = CTRL_getVq_out_pu(handle);

  // calculate vector Vs in per units
  gMotorVars.Vs = _IQsqrt(_IQmpy(gMotorVars.Vd, gMotorVars.Vd) + _IQmpy(gMotorVars.Vq, gMotorVars.Vq));

  CTRL_setVsFdb(handle, gMotorVars.Vs);
  CTRL_setVsRef(handle, gMotorVars.VsRef);

  // read Id and Iq vectors in amps
  gMotorVars.Id_A = _IQmpy(CTRL_getId_in_pu(handle), _IQ(USER_IQ_FULL_SCALE_CURRENT_A));
  gMotorVars.Iq_A = _IQmpy(CTRL_getIq_in_pu(handle), _IQ(USER_IQ_FULL_SCALE_CURRENT_A));

  // calculate vector Is in amps
  gMotorVars.Is_A = _IQsqrt(_IQmpy(gMotorVars.Id_A, gMotorVars.Id_A) + _IQmpy(gMotorVars.Iq_A, gMotorVars.Iq_A));

  return;
} // end of updateGlobalVariables_motor() function


void updateKpKiGains(CTRL_Handle handle)
{
  if((gMotorVars.CtrlState == CTRL_State_OnLine) && (gMotorVars.Flag_MotorIdentified == true) && (Flag_Latch_softwareUpdate == false))
    {
      // set the kp and ki speed values from the watch window
      CTRL_setKp(handle,CTRL_Type_PID_spd,gMotorVars.Kp_spd);
      CTRL_setKi(handle,CTRL_Type_PID_spd,gMotorVars.Ki_spd);

      // set the kp and ki current values for Id and Iq from the watch window
      CTRL_setKp(handle,CTRL_Type_PID_Id,gMotorVars.Kp_Id);
      CTRL_setKi(handle,CTRL_Type_PID_Id,gMotorVars.Ki_Id);
      CTRL_setKp(handle,CTRL_Type_PID_Iq,gMotorVars.Kp_Iq);
      CTRL_setKi(handle,CTRL_Type_PID_Iq,gMotorVars.Ki_Iq);
	}

  return;
} // end of updateKpKiGains() function


void ST_runPosConv(ST_Handle handle, ENC_Handle encHandle, CTRL_Handle ctrlHandle)
{
	ST_Obj *stObj = (ST_Obj *)handle;

	// get the electrical angle from the ENC module
    STPOSCONV_setElecAngle_erev(stObj->posConvHandle, ENC_getElecAngle(encHandle));

    if(USER_MOTOR_TYPE ==  MOTOR_Type_Induction)
    {
      // The CurrentVector feedback is only needed for ACIM
      // get the vector of the direct/quadrature current input vector values from CTRL
      STPOSCONV_setCurrentVector(stObj->posConvHandle, CTRL_getIdq_in_addr(ctrlHandle));
    }

	// run the SpinTAC Position Converter
	STPOSCONV_run(stObj->posConvHandle);

	if(USER_MOTOR_TYPE ==  MOTOR_Type_Induction) {
	  // The Slip Velocity is only needed for ACIM
	  // update the slip velocity in electrical angle per second, Q24
	  SLIP_setSlipVelocity(slipHandle, STPOSCONV_getSlipVelocity(stObj->posConvHandle));
	}
}

void ST_runPosCtl(ST_Handle handle, CTRL_Handle ctrlHandle)
{
	ST_Obj *stObj = (ST_Obj *)handle;

	// provide the updated references to the SpinTAC Position Control
	STPOSCTL_setPositionReference_mrev(stObj->posCtlHandle, STPOSMOVE_getPositionReference_mrev(stObj->posMoveHandle));
	STPOSCTL_setVelocityReference(stObj->posCtlHandle, STPOSMOVE_getVelocityReference(stObj->posMoveHandle));
	STPOSCTL_setAccelerationReference(stObj->posCtlHandle, STPOSMOVE_getAccelerationReference(stObj->posMoveHandle));
	// provide the feedback to the SpinTAC Position Control
	STPOSCTL_setPositionFeedback_mrev(stObj->posCtlHandle, STPOSCONV_getPosition_mrev(stObj->posConvHandle));

	// Run SpinTAC Position Control
	STPOSCTL_run(stObj->posCtlHandle);
	
	// Provide SpinTAC Position Control Torque Output to the FOC
	CTRL_setIq_ref_pu(ctrlHandle, STPOSCTL_getTorqueReference(stObj->posCtlHandle));
}

void ST_runPosMove(ST_Handle handle)
{
	ST_Obj *stObj = (ST_Obj *)handle;

	// Run SpinTAC Position Profile Generator
	// If we are not running a profile, and the PosStep_MRev has been modified
	if(_IQmpy(gMotorVars.MaxVel_krpm, _IQ(ST_SPEED_PU_PER_KRPM)) != STPOSMOVE_getVelocityEnd(stObj->posMoveHandle)) {
		// Get the configuration for SpinTAC Velocity Profile Generator
		STPOSMOVE_setCurveType(stObj->posMoveHandle, gMotorVars.SpinTAC.PosMoveCurveType);
		STPOSMOVE_setProfileType(stObj->posMoveHandle, ST_POS_MOVE_VEL_TYPE);
		STPOSMOVE_setVelocityEnd(stObj->posMoveHandle, _IQmpy(gMotorVars.MaxVel_krpm, _IQ(ST_SPEED_PU_PER_KRPM)));
		STPOSMOVE_setAccelerationLimit(stObj->posMoveHandle, _IQmpy(gMotorVars.MaxAccel_krpmps, _IQ(ST_SPEED_PU_PER_KRPM)));
		STPOSMOVE_setDecelerationLimit(stObj->posMoveHandle, _IQmpy(gMotorVars.MaxDecel_krpmps, _IQ(ST_SPEED_PU_PER_KRPM)));
		STPOSMOVE_setJerkLimit(stObj->posMoveHandle, _IQ20mpy(gMotorVars.MaxJrk_krpmps2, _IQ20(ST_SPEED_PU_PER_KRPM)));
		// Enable the SpinTAC Position Profile Generator
		STPOSMOVE_setEnable(stObj->posMoveHandle, true);
	}

	STPOSMOVE_run(stObj->posMoveHandle);
}
//---------------------------------------------------------------------------------
void runRsOnLine(CTRL_Handle handle)
{
  CTRL_Obj *obj = (CTRL_Obj *)handle;

  // execute Rs OnLine code
  if((EST_getState(obj->estHandle) == EST_State_OnLine) && (gMotorVars.Flag_enableRsOnline))
    {
      EST_setFlag_enableRsOnLine(obj->estHandle,true);
      EST_setRsOnLineId_mag_pu(obj->estHandle,_IQmpy(gMotorVars.RsOnLineCurrent_A,_IQ(1.0/USER_IQ_FULL_SCALE_CURRENT_A)));

      if((gMotorVars.RsOnLine_Ohm > USER_MOTOR_Rs_N55C) && (gMotorVars.RsOnLine_Ohm < USER_MOTOR_Rs_P120C))
      {
           float_t RsError_Ohm = gMotorVars.RsOnLine_Ohm - gMotorVars.Rs_Ohm;

           if(abs(RsError_Ohm) < (gMotorVars.Rs_Ohm * 0.05))
            {
              EST_setFlag_updateRs(obj->estHandle,true);
            }
      }
    }
  else
    {
      EST_setRsOnLineId_mag_pu(obj->estHandle,_IQ(0.0));
      EST_setRsOnLineId_pu(obj->estHandle,_IQ(0.0));
      EST_setRsOnLine_pu(obj->estHandle, EST_getRs_pu(obj->estHandle));
      EST_setFlag_enableRsOnLine(obj->estHandle,false);
      EST_setFlag_updateRs(obj->estHandle,false);
      EST_setRsOnLine_qFmt(obj->estHandle,EST_getRs_qFmt(obj->estHandle));
    }

  return;
} // end of runRsOnLine() function
//---------------------------------------------------------------------------------
void recalcKpKiPmsm(CTRL_Handle handle)
{
  CTRL_Obj *obj = (CTRL_Obj *)handle;
  EST_State_e EstState = EST_getState(obj->estHandle);

  if((EST_isMotorIdentified(obj->estHandle) == false) && (EstState == EST_State_Rs))
    {
      float_t Lhf = CTRL_getLhf(handle);
      float_t Rhf = CTRL_getRhf(handle);
      float_t RhfoverLhf = Rhf/Lhf;
      _iq Kp = _IQ(0.05*Lhf*USER_IQ_FULL_SCALE_CURRENT_A/(USER_CTRL_PERIOD_sec*USER_IQ_FULL_SCALE_VOLTAGE_V));
      _iq Ki = _IQ(RhfoverLhf*USER_CTRL_PERIOD_sec);
      _iq Kp_spd = _IQ(0.005*USER_IQ_FULL_SCALE_FREQ_Hz*USER_MOTOR_MAX_CURRENT/USER_IQ_FULL_SCALE_CURRENT_A);

      // set Rhf/Lhf
      CTRL_setRoverL(handle,RhfoverLhf);

      // set the controller proportional gains
      CTRL_setKp(handle,CTRL_Type_PID_Id,Kp);
      CTRL_setKp(handle,CTRL_Type_PID_Iq,Kp);

      // set the Id controller gains
      CTRL_setKi(handle,CTRL_Type_PID_Id,Ki);
      PID_setKi(obj->pidHandle_Id,Ki);

      // set the Iq controller gains
      CTRL_setKi(handle,CTRL_Type_PID_Iq,Ki);
      PID_setKi(obj->pidHandle_Iq,Ki);

      // set speed gains
      PID_setKp(obj->pidHandle_spd,Kp_spd);
    }
  else if(EstState == EST_State_RatedFlux)
    {
      _iq Ki_spd = _IQ(0.5*USER_IQ_FULL_SCALE_FREQ_Hz*USER_CTRL_PERIOD_sec*USER_MOTOR_MAX_CURRENT/USER_IQ_FULL_SCALE_CURRENT_A);

      // Set Ki on closing the feedback loop
      PID_setKi(obj->pidHandle_spd,Ki_spd);
    }
  else if(EstState == EST_State_RampDown)
    {
      _iq Kp_spd = _IQ(0.02*USER_IQ_FULL_SCALE_FREQ_Hz*USER_MOTOR_MAX_CURRENT/USER_IQ_FULL_SCALE_CURRENT_A);
      _iq Ki_spd = _IQ(2.0*USER_IQ_FULL_SCALE_FREQ_Hz*USER_CTRL_PERIOD_sec*USER_MOTOR_MAX_CURRENT/USER_IQ_FULL_SCALE_CURRENT_A);

      // Set Kp and Ki of the speed controller
      PID_setKp(obj->pidHandle_spd,Kp_spd);
      PID_setKi(obj->pidHandle_spd,Ki_spd);

      TRAJ_setTargetValue(obj->trajHandle_spdMax,_IQ(USER_MOTOR_RES_EST_CURRENT/USER_IQ_FULL_SCALE_CURRENT_A));
    }

  return;
} // end of recalcKpKiPmsm() function

void recalcKpKi(CTRL_Handle handle)
{
  CTRL_Obj *obj = (CTRL_Obj *)handle;
  EST_State_e EstState = EST_getState(obj->estHandle);

  if((EST_isMotorIdentified(obj->estHandle) == false) && (EstState == EST_State_Rs))
    {
      float_t Lhf = CTRL_getLhf(handle);
      float_t Rhf = CTRL_getRhf(handle);
      float_t RhfoverLhf = Rhf/Lhf;
      _iq Kp = _IQ(0.25*Lhf*USER_IQ_FULL_SCALE_CURRENT_A/(USER_CTRL_PERIOD_sec*USER_IQ_FULL_SCALE_VOLTAGE_V));
      _iq Ki = _IQ(RhfoverLhf*USER_CTRL_PERIOD_sec);

      // set Rhf/Lhf
      CTRL_setRoverL(handle,RhfoverLhf);

      // set the controller proportional gains
      CTRL_setKp(handle,CTRL_Type_PID_Id,Kp);
      CTRL_setKp(handle,CTRL_Type_PID_Iq,Kp);

      // set the Id controller gains
      CTRL_setKi(handle,CTRL_Type_PID_Id,Ki);
      PID_setKi(obj->pidHandle_Id,Ki);

      // set the Iq controller gains
      CTRL_setKi(handle,CTRL_Type_PID_Iq,Ki);
      PID_setKi(obj->pidHandle_Iq,Ki);
    }

  return;
} // end of recalcKpKi() function

//---------------------------------------------------------------------------------
void CTRL_resetLs_qFmt(CTRL_Handle handle, const uint_least8_t Ls_qFmt)
{
  CTRL_Obj *obj = (CTRL_Obj *)handle;
  static bool LsResetLatch = false;

  // reset Ls Q format to a higher value when Ls identification starts
  if(EST_getState(obj->estHandle) == EST_State_Ls)
    {
      if((EST_getLs_d_pu(obj->estHandle) != _IQ30(0.0)) && (LsResetLatch == false))
        {
          EST_setLs_qFmt(obj->estHandle, Ls_qFmt);
          LsResetLatch = true;
        }
    }
  else
    {
      LsResetLatch = false;
    }

  return;
} // end of CTRL_resetLs_qFmt() function


void CTRL_calcMax_Ls_qFmt(CTRL_Handle handle, uint_least8_t *pLs_qFmt)
{
  CTRL_Obj *obj = (CTRL_Obj *)handle;

  if((EST_isMotorIdentified(obj->estHandle) == false) && (EST_getState(obj->estHandle) == EST_State_Rs))
    {
      float_t Lhf = CTRL_getLhf(handle);
      float_t fullScaleInductance = USER_IQ_FULL_SCALE_VOLTAGE_V/(USER_IQ_FULL_SCALE_CURRENT_A*USER_VOLTAGE_FILTER_POLE_rps);
      float_t Ls_coarse_max = _IQ30toF(EST_getLs_coarse_max_pu(obj->estHandle));
      int_least8_t lShift = ceil(log((Lhf/20.0)/(Ls_coarse_max*fullScaleInductance))/log(2.0));

      *pLs_qFmt = 30 - lShift;
    }

  return;
} // end of CTRL_calcMax_Ls_qFmt() function


void setFeLimitZero(CTRL_Handle handle)
{
  CTRL_Obj *obj = (CTRL_Obj *)handle;
  EST_State_e EstState = EST_getState(obj->estHandle);

  _iq fe_neg_max_pu;
  _iq fe_pos_min_pu;

  if((EST_isMotorIdentified(obj->estHandle) == false) && (CTRL_getMotorType(handle) == MOTOR_Type_Induction))
    {
      fe_neg_max_pu = _IQ30(0.0);

      fe_pos_min_pu = _IQ30(0.0);
    }
  else
    {
      fe_neg_max_pu = _IQ30(-USER_ZEROSPEEDLIMIT);

      fe_pos_min_pu = _IQ30(USER_ZEROSPEEDLIMIT);
    }

  EST_setFe_neg_max_pu(obj->estHandle, fe_neg_max_pu);

  EST_setFe_pos_min_pu(obj->estHandle, fe_pos_min_pu);

  return;
} // end of setFeLimitZero() function


void acim_Dir_qFmtCalc(CTRL_Handle handle)
{
  CTRL_Obj *obj = (CTRL_Obj *)handle;
  EST_State_e EstState = EST_getState(obj->estHandle);

  if(EstState == EST_State_IdRated)
    {
      EST_setDir_qFmt(obj->estHandle, EST_computeDirection_qFmt(obj->estHandle, 0.7));
    }

  return;
} // end of acim_Dir_qFmtCalc() function

//@} //defgroup
// end of file
